﻿* Encoding: windows-1252.
* v-2018-11-26 .

*	SPSS syntax files for calculating and appending background variables to SPSS MICS data files
	This program should be run after the data sets have been exported from CSPro, and structural checks have been completed
	Usually, several runs of this program will be needed before the creation of background variables are finalized and merged to the data sets for good
	The data processing expert should check the frequency distribution of created variables
	With every run of the program, background variables will be replaced with the new values of the variables
	Added variables are: EDUCATION,  ETHNICITY/LANGUAGE/RELIGION and AGE AT THE BEGINING OF SCHOOL YEAR.


*  CREATE BACKGROUND CHARACTERISTICS TEMPORARY FILES .

* Open the household data file.
get file = 'hh.sav'.

sort cases by HH1 HH2.

* ethinicity already created .
delete variables ethnicity.

recode HC2  (1=1) (2=2) (3=3) (96=7) (else = 9) into ethnicity.
value labels ethnicity 
1 "Group 1" 
2 "Group 2" 
3 "Group 3" 
6 "Other ethnicity"  
9 "Missing/DK".
variable labels ethnicity "Ethnicity of household head".
formats ethnicity (f1.0).

* Reset variables for incomplete interviews.
if (HH46 ~= 1) ethnicity = $SYSMIS .

* Save the hh data file with ethinicity and education of hh head.
save outfile = 'hh.sav' .

save outfile = tmpEthnicity.sav 
  /keep HH1 HH2 ethnicity.

new file.

* Open the household listing data file.
get file = 'hl.sav'.

* Delete variables if previously created.
delete variables ethnicity helevel melevel felevel.

* Sort the cases by cluster number, household number and line number.
sort cases by HH1 HH2 HL1.

* Customize the household head education level categories.
recode ED5A (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0) into helevel.
variable labels helevel "Education of household head".
value labels helevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  9 "Missing/DK".
formats helevel (f1.0).

* Check if variables are properly recoded, by cross tabulating recoded and original variable.
crosstabs ED5A by helevel.

* Filter household heads only.
compute headFilter = (HL3 = 1).
filter by headFilter .

* Save a data file of household heads with IDs and education as only vars.
save outfile = 'tmphelevel.sav'
  /unselected = delete
  /keep HH1 HH2 helevel.

filter off.
  
* Melevel: create mother education level tmp file.
* allow for code 5 - cases when mother is not in household.
recode ED5A (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0) into melevel.
variable labels melevel "Mother’s education".
value labels melevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  5 "No information"
  9 "Missing/DK".
formats melevel (f1.0).

* Check if variables are properly recoded, by cross tabulating recoded and original variable.
crosstabs ED5A by melevel.

* Save a mother's education file.
save outfile = 'tmpmelevel.sav'
  /keep HH1 HH2 HL1 melevel
  /rename HL1 = mline.
  
* felevel: create father's education level tmp file .
* same as in the case of mothers education allow for code 5 - cases when father is not in the household.
recode ED5A (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0)  into felevel.
variable labels felevel "Father's education".
value labels felevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  5 "No information"
  9 "Missing/DK".
formats felevel (f1.0).

* Check if variables are properly recoded, by cross tabulating recoded and original variable.
crosstabs ED5A by felevel.

* Save a father's education file.
save outfile = 'tmpfelevel.sav'
  /keep HH1 HH2 HL1 felevel
  /rename HL1 = fline.
  

* MERGE BACGROUND VARIABLES FROM TMP FILES .

* Open the household data file.
get file = 'hh.sav'.

sort cases by hh1 hh2.

delete variables ethnicity helevel .

* Merge the household head education file onto the household file.
match files
  /file = *
  /table = 'tmphelevel.sav'
  /by HH1 HH2 .

* Save the hh data file with ethinicity and education of hh head.
save outfile = 'hh.sav' .

new file.

* Open the household members data file.
get file = 'hl.sav'.

* Sort the cases by cluster number, household number and line number.
sort cases by HH1 HH2 HL1.

* delete variables if already existing.
delete variables ethnicity helevel melevel felevel schage.

* Merge the household head ethnicity file onto the household listing file.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2 .
  
* Merge the household head education file onto the household listing file.
match files
  /file = *
  /table = 'tmphelevel.sav'
  /by HH1 HH2 .

* Sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* Merge the mother's education file onto the household listing file.
match files
  /file = *
  /table = 'tmpmelevel.sav'
  /by HH1 HH2 mline.

* Recode mother's education level to deal with mothers who live elsewhere or are dead.
if (mline = 0) melevel = 5.

* Sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* Merge the father's education file onto the household listing file.
match files
  /file = *
  /table = 'tmpfelevel.sav'
  /by HH1 HH2 fline.

* Recode father's education level to deal with fathers who live elsewhere or are dead.
if (fline = 0) felevel = 5.

* Set the month and year of the beginning of the school year in your country.
compute monthSc =  9.
compute yearSc =  2018.
variable labels monthSc "Month of beginning of the school year".
variable labels yearSc "Year of beginning of the school year".

compute schage = 998.
* if month and year of birth are valid.
if (HL5M < 97  and HL5Y < 9997) schage =  trunck ( (yearSc - HL5Y)  + (monthSc - HL5M) / 12).
* if month or year of birth infomration is missing, and survey was conducted half a year or later than the beginning of the school year.
if (HL5M >= 97 or HL5Y >= 9997) and HL6 < 95 and ((HH5Y - yearSc) *12 + (HH5M - monthSc) >= 6) schage = HL6 - 1.
* if month or year of birth infomration is missing, and survey was conducted 0 - 5 months before than the beginning of the school year.
if (HL5M >= 97 or HL5Y >= 9997) and HL6 < 95 and ((HH5Y - yearSc) *12 + (HH5M - monthSc) < 6) schage = HL6.
* if a child is born after beginning of school year set value to 995.
if ( ((HL5M < 97  and HL5Y < 9997) and (yearSc - HL5Y)  + (monthSc - HL5M) / 12 < 0) or schage < 0) schage = 995.

formats schage (f3.0).
variable labels schage "Age at beginning of school year".
value labels schage
995 "Child  born after beginning of school year"
998 "DK/Missing".
execute.

* Delete working variables.
delete variables  monthSc.
delete variables  yearSc.

* Sort the cases by cluster number, household number and line number.
sort cases by HH1 HH2 HL1 .

* Save the household listing data file.
save outfile = 'hl.sav'.

new file .
  

* Open the women file.
get file ="wm.sav".

* welevel: calculate woman's education level.

delete variables ethnicity welevel insurance disability migration.

recode WB6A (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0) into welevel.
variable labels welevel "Education".
value labels welevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  9 "Missing/DK".
formats welevel (f1.0).

compute insurance = WB18.
variable labels insurance "Health insurance".
value labels insurance
 1 "With insurance"
 2 "Without insurance" 
 9 "Missing/DK".

* (AF6A/B=3 or 4 OR AF8A/B=3 or 4 OR AF9=3 or 4 OR AF10=3 or 4 OR AF11=3 or 4 OR AF12=3 or 4).
do if (WB4 >= 18).
compute disability = 2.
if (AF6 = 3 or AF6 = 4) disability = 1.
if (AF8 = 3 or AF8 = 4) disability = 1.
if (AF9 = 3 or AF9 = 4) disability = 1.
if (AF10 = 3 or AF10 = 4) disability = 1.
if (AF11 = 3 or AF11 = 4) disability = 1.
if (AF12 = 3 or AF12 = 4) disability = 1.
end if.
variable labels disability "Functional difficulties (age 18-49 years)".
value labels disability 
 1 "Has functional difficulty"
 2 "Has no functional difficulty".

recode WB15 (5 thru 94 = 3) (95 = 1) (99 = 9) (else = 2) into migration.

value labels migration
   1 "Never moved from present location"
   2 "Moved within the last 5 years"
   3 "Moved 5+ years ago"
   9 "Missing".

* Reset variables for incomplete interviews.
if (WM17 ~= 1) welevel = $SYSMIS .
if (WM17 ~= 1) disability = $SYSMIS .
if (WM17 ~= 1) migration = $SYSMIS .
if (WM17 ~= 1) insurance = $SYSMIS .

* Sort by cluster number and household number.
sort cases by HH1 HH2 LN.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2.

* Save the women's file.
save outfile = 'wm.sav'.

* Save a data file of women with IDs and education as only vars.
save outfile = 'tmpwelevel.sav'
  /keep HH1 HH2 LN welevel disability migration insurance.

new file.

* Open the men file.
get file ="mn.sav".

delete variables ethnicity mwelevel minsurance mdisability mmigration.

recode MWB6A (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0) into mwelevel.
variable labels mwelevel "Education".
value labels mwelevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  9 "Missing/DK".
formats mwelevel (f1.0).

compute minsurance = MWB18.
variable labels minsurance "Health insurance".
value labels minsurance
 1 "With insurance"
 2 "Without insurance" 
 9 "Missing/DK".

do if (MWB4 >= 18).
compute mdisability = 2.
if (MAF6 = 3 or MAF6 = 4) mdisability = 1.
if (MAF8 = 3 or MAF8 = 4) mdisability = 1.
if (MAF9 = 3 or MAF9 = 4) mdisability = 1.
if (MAF10 = 3 or MAF10 = 4) mdisability = 1.
if (MAF11 = 3 or MAF11 = 4) mdisability = 1.
if (MAF12 = 3 or MAF12 = 4) mdisability = 1.
end if.
variable labels mdisability "Functional difficulties (age 18-49 years)".
value labels mdisability 
 1 "Has functional difficulty"
 2 "Has no functional difficulty".

recode MWB15 (5 thru 94 = 3) (95 = 1) (99 = 9) (else = 2) into mmigration.

value labels mmigration
   1 "Never moved from present location"
   2 "Moved within the last 5 years"
   3 "Moved 5+ years ago"
   9 "Missing".

* Reset variables for incomplete interviews.
if (MWM17 ~= 1) mwelevel = $SYSMIS .
if (MWM17 ~= 1) mdisability = $SYSMIS .
if (MWM17 ~= 1) mmigration = $SYSMIS .
if (MWM17 ~= 1) minsurance = $SYSMIS .

* Sort by cluster number and household number.
sort cases by HH1 HH2 LN.
* add ethnicity variable to man file.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2.

* Save the men's file.
save outfile = 'mn.sav'.

new file .
  
  
*** Open the children file.
get file ="ch.sav".

* melevel: calculate education level of mother.
delete variables ethnicity melevel cinsurance cdisability caretakerdis.

* mother education from ED4A that was mergend during the export .
recode ED5A  (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0) into melevel.
variable labels melevel "Mother's education".
value labels melevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  9 "Missing/DK".
formats melevel (f1.0).

compute cinsurance = UB9.
variable labels cinsurance "Health insurance".
value labels cinsurance
 1 "With insurance"
 2 "Without insurance" 
 9 "Missing/DK".

*Seeing (UCF7A/B=3 or 4), Hearing (UCF9A/B=3 or 4).
*Walking (UCF11=3 or 4 OR UCF12=3 or 4 OR UCF13=3 or 4).
*Fine motor (UCF14=3 or 4), Communication.
*a) Understanding (UCF15=3 or 4) or b) Being understood (UCF16=3 or 4), Learning (UCF17=3 or 4), Playing (UCF18=3 or 4), Controlling behaviour (UCF19=5).

do if (UB2 >= 2).
compute cdisability = 2.
if (UCF7 = 3 or UCF7 = 4) cdisability = 1.
if (UCF9 = 3 or UCF9 = 4) cdisability = 1.
if (UCF11 = 3 or UCF11 = 4) cdisability = 1.
if (UCF12 = 3 or UCF12 = 4) cdisability = 1.
if (UCF13 = 3 or UCF13 = 4) cdisability = 1.
if (UCF14 = 3 or UCF14 = 4) cdisability = 1.
if (UCF15 = 3 or UCF15 = 4) cdisability = 1.
if (UCF16 = 3 or UCF16 = 4) cdisability = 1.
if (UCF17 = 3 or UCF17 = 4) cdisability = 1.
if (UCF18 = 3 or UCF18 = 4) cdisability = 1.
if (UCF19 = 5) cdisability = 1.
end if.
variable labels cdisability "Child's functional difficulties (age 2-4 years)".
value labels cdisability 
 1 "Has functional difficulty"
 2 "Has no functional difficulty".

* Reset variables for incomplete interviews.
if (UF17 ~= 1) cdisability = $SYSMIS .
if (UF17 ~= 1) cinsurance = $SYSMIS .

* Sort by cluster number and household number, and line number.
sort cases by HH1 HH2 LN.

* add ethnicity variable to children file.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2.

* Save the children's file.
save outfile = 'ch.sav'.

new file .

* Add caretaker's disability.
get file = "wm.sav".
sort cases by hh1 hh2 ln.
save outfile "moddis1.sav" /keep hh1 hh2 ln disability /rename ln = uf4 disability = caretakerdis.

get file = "mn.sav".
sort cases by hh1 hh2 ln.
save outfile "moddis2.sav" /keep hh1 hh2 ln mdisability /rename ln = uf4 mdisability = caretakerdis.

get file ="ch.sav".
sort cases by hh1 hh2 uf4.

* Merge the caretakers disability.
match files
  /file = *
  /table = 'moddis1.sav'
  /table = 'moddis2.sav'
  /by HH1 HH2 UF4.

sort cases by hh1 hh2 ln.
recode caretakerdis (sysmis = 9)(else = copy).
add value labels caretakerdis 9 "No information".

save outfile = "ch.sav".

  
*** Open the children file.
get file ="fs.sav".

* melevel: calculate education level of mother.
delete variables ethnicity fselevel fsinsurance fsdisability melevel caretakerdis.

recode CB5A    (1 = 1) (2, 3, 4, 5 = 2)(8,9 = 9) (else = 0)  into fselevel.
variable labels fselevel "Child's education".
value labels fselevel
  0 "Pre-primary or none"
  1 "Primary"
  2 "Secondary + "
  9 "Missing/DK".
formats fselevel (f1.0).


* Set the month and year of the beginning of the school year in your country.
compute monthSc =  9.
compute yearSc =  2018.
variable labels monthSc "Month of beginning of the school year".
variable labels yearSc "Year of beginning of the school year".

compute schage = 998.
* if month and year of birth are valid.
if (CB2M < 97  and CB2Y < 9997) schage =  trunck ( (yearSc - CB2Y)  + (monthSc - CB2M) / 12).
* if month or year of birth infomration is missing, and survey was conducted half a year or later than the beginning of the school year.
if (CB2M >= 97 or CB2Y >= 9997) and CB3 < 95 and ((FS7Y - yearSc) *12 + (FS7M - monthSc) >= 6) schage = CB3 - 1.
* if month or year of birth infomration is missing, and survey was conducted 0 - 5 months before than the beginning of the school year.
if (CB2M >= 97 or CB2Y >= 9997) and CB3 < 95 and ((FS7Y - yearSc) *12 + (FS7M - monthSc) < 6) schage = CB3.

formats schage (f3.0).
variable labels schage "Age at beginning of school year".
value labels schage
998 "DK/Missing".
execute.

* Delete working variables.
delete variables  monthSc.
delete variables  yearSc.

compute fsinsurance = CB11.
variable labels fsinsurance "Health insurance".
value labels fsinsurance
 1 "With insurance"
 2 "Without insurance" 
 9 "Missing/DK".

compute fsdisability = 2.
if (FCF6 = 3 or FCF6 = 4) fsdisability = 1.
if (FCF8 = 3 or FCF8 = 4) fsdisability = 1.
if (FCF10 = 3 or FCF10 = 4) fsdisability = 1.
if (FCF11 = 3 or FCF11 = 4) fsdisability = 1.
*if (FCF12 = 3 or FCF12 = 4) fsdisability = 1.
*if (FCF13 = 3 or FCF13 = 4) fsdisability = 1.
if (FCF14 = 3 or FCF14 = 4) fsdisability = 1.
if (FCF15 = 3 or FCF15 = 4) fsdisability = 1.
if (FCF16 = 3 or FCF16 = 4) fsdisability = 1.
if (FCF17 = 3 or FCF17 = 4) fsdisability = 1.
if (FCF18 = 3 or FCF18 = 4) fsdisability = 1.
if (FCF19 = 3 or FCF19 = 4) fsdisability = 1.
if (FCF20 = 3 or FCF20 = 4) fsdisability = 1.
if (FCF21 = 3 or FCF21 = 4) fsdisability = 1.
if (FCF22 = 3 or FCF22 = 4) fsdisability = 1.
if (FCF23 = 3 or FCF23 = 4) fsdisability = 1.
if (FCF24 = 3 or FCF24 = 4) fsdisability = 1.
if (FCF25 = 1) fsdisability = 1.
if (FCF26 = 1) fsdisability = 1.
variable labels fsdisability "Child's functional difficulties (age 5-17years)".
value labels fsdisability 
 1 "Has functional difficulty"
 2 "Has no functional difficulty".


* Reset variables for incomplete interviews.
if (FS17 ~= 1) fsdisability = $SYSMIS .
if (FS17 ~= 1) fsnsurance = $SYSMIS .
if (FS17 ~= 1) fselevel = $SYSMIS .

* Sort by cluster number and household number, and line number.
sort cases by HH1 HH2 LN.

* add ethnicity variable to children file.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2.

* Save the children's file.
save outfile = 'fs.sav'.

new file .

get file 'moddis1.sav'.
rename variables uf4 = fs4.
save outfile 'moddis1.sav'.

get file 'moddis2.sav'.
rename variables uf4 = fs4.
save outfile 'moddis2.sav'.

get file = "tmpmelevel.sav".
rename variables mline = fs4.
save outfile = "tmpmelevel.sav".

get file ="fs.sav".
sort cases by hh1 hh2 fs4.

* Merge the caretakers disability.
match files
  /file = *
  /table = 'moddis1.sav'
  /table = 'moddis2.sav'
  /table = 'tmpmelevel.sav'
  /by HH1 HH2 FS4.

sort cases by hh1 hh2 ln.

if sysmis(melevel) melevel = fselevel.

recode caretakerdis (sysmis = 9)(else = copy).
add value labels caretakerdis 9 "No information".

save outfile = "fs.sav".


* Open the ITN data file.
get file = 'tn.sav'.

delete variables helevel ethnicity.

* Sort the cases by cluster number and household number.
sort cases by HH1 HH2.

* Merge the household head education.
match files
  /file = *
  /table = 'tmphelevel.sav'
  /by HH1 HH2 .

* Merge the household head ethnicity.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2 .

* Save household data, which now contains the education of household head.
save outfile = 'tn.sav'.

* Open the female genital cutting data file.
get file = 'fg.sav'.

delete variables ethnicity welevel.

* Sort the cases by cluster number and household number.
sort cases by HH1 HH2 LN.

* Merge the household head ethnicity.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2.

* Merge the women's education.
match files
  /file = *
  /table = 'tmpwelevel.sav'
  /by HH1 HH2 LN.

* Save fg data.
save outfile = 'fg.sav'.

new file .


* Open the birth history data file.
get file = 'bh.sav'.

delete variables ethnicity welevel insurance disability migration.
* Sort the cases by cluster number and household number.
sort cases by HH1 HH2 LN BHLN.

* Merge the household head ethnicity.
match files
  /file = *
  /table = 'tmpEthnicity.sav'
  /by HH1 HH2 .

* Merge the mother's education.
match files
  /file = *
  /table = 'tmpwelevel.sav'
  /by HH1 HH2 LN.

* Create birth order, birth interval and mother's age at birth variables.
sort cases by HH1 HH2 LN BHLN.

delete variables BHLN brthord magebrt birthint.

compute BHLN=BH0.
* Create birth order, birth interval and mother's age at birth variables.
sort cases by HH1 HH2 LN BHLN.

recode BHLN (1 = 1) (2,3 = 2) (4,5,6 = 3) (else = 4) into brthord.
compute magebrt = BH4C - WDOB.
recode magebrt (lo thru 239 = 1) (240 thru 419 = 2) (420 thru hi = 3).

* Not twin and not first.
if (BH4C <> lag(BH4C) and BHLN > 1) birthint = BH4C - lag(BH4C).
* Twin and not first.
if (BH4C = lag(BH4C) and BH4C <> lag(BH4C,2) and BHLN > 2) birthint = BH4C - lag(BH4C,2).
* Triplet and not first.
if (BH4C = lag(BH4C) and BH4C = lag(BH4C,2) and BH4C <> lag(BH4C,3) and BHLN > 3) birthint = BH4C - lag(BH4C,3).
recode birthint (sysmis=0) (lo thru 23=1) (24 thru 35=2) (36 thru 47=3) (48 thru hi=4).

variable labels 
  brthord 'Birth order'
 /magebrt "Mother's age at birth"
 /birthint "Previous birth interval".
value labels
  brthord 1 '1' 2 '2-3' 3 '4-6' 4 '7+'
 /magebrt 1 '<20' 2 '20-34' 3 '35+'
 /birthint 0 'First birth' 1 '<2 years' 2 '2 years' 3 '3 years' 4 '4+ years'.

* Save bh data, which now contains new variables .
save outfile = 'bh.sav'.

new file.

*erase the working files.
erase file = 'tmphelevel.sav'.
erase file = 'tmpEthnicity.sav'.
erase file = 'tmpmelevel.sav'.
erase file = 'tmpfelevel.sav'.
erase file = 'tmpwelevel.sav'.
erase file = 'moddis1.sav'.
erase file = 'moddis2.sav'.
