﻿* Encoding: windows-1252.
* MICS6 SR.1.1.

* v01 - 2018-01-28.
* v02 - 2019-08-27. Last modified to reflect tab plan changes as of 25 July 2019.

** The denominator for the household response rate is the number of households found to be occupied during fieldwork (HH46 = 01, 02, 04, 07); the numerator is the number of households with complete household questionnaires (HH46 = 01).
** The denominator for the women’s response rate is the number of eligible women enumerated in the household listing form (HH49); the numerator is the number of women with a complete interview (HH53). 
** The denominator for the men's response rate is the number of eligible men enumerated in the household listing form (HH50); the numerator is the number of men with a complete interview (HH54). 
** The denominator for the response rate for the questionnaire for children under 5 is the number of under-5 children identified in the household listing form (HH51); the numerator is the number of complete questionnaires for children under 5 (HH55).
** The denominator for the response rate for the questionnaire for children age 5-17 is the number of children age 5-17 identified in the household listing form (HH52); 
    the numerator is the number of complete questionnaires for children under 5 (HH56).
** Overall response rates are calculated for women, men, under-5 and children age 5-17 by multiplying the household response rate by the women's, men's, under-5's and children age 5-17's response rates, respectively.


******.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open the household data file.
get file = 'hh.sav'.

* Give value 1 to each HH to calculate total number of hhs sampled.
compute sampled = 1.

* Give value 1 to each HH occupied to calculate total number of hhs occupied.
recode HH46 (1,2,4,7 = 1) (else = 0) into occupied.

* Give value 1 to each hh interviewed to calculate total no of interviewed HHs.
recode HH46 (1 = 1) (else = 0) into complete.

recode HH52 (1 thru hi = 1)(else = 0) into HH52A.

* Give value 1 to each hh selected for water quality test.
recode HH9 (1 = 1) (else = 0) into wqSelect.
* exclude cases with incomplete household interview.
if HH46 <> 1 wqSelect = 0.

* Give value 1 to each water quality test completed at household.
recode WQ11 (1 = 1) (else = 0) into wqhhcomplete.

* Give value 1 to each water quality test completed at source.
recode WQ19 (1 = 1) (else = 0) into wqsocomplete.

compute total = 1.
variable labels total "".
value labels total 1 "Total".

* For urban and rural separately.
* Aggregate the hh data file to calculate the sum of sampled, occupied, complete HHs.
* and sum of eligible and interviewed wmTot age 15-49 and children under age 5.
aggregate outfile = 'tmp1.sav'
  /break   = HH6
  /hhSamp  = sum(sampled)
  /hhOccup = sum(occupied)
  /hhComp  = sum(complete)
  /wqSel  = sum(wqSelect)
  /wqhhComp  = sum(wqhhcomplete)
  /wqsoComp  = sum(wqsocomplete)
  /wmTot   = sum(HH49)
  /wmComp  = sum(HH53)
  /mnAll  = sum(HH50A)
  /mnTot   = sum(HH50)
  /mnComp  = sum(HH54)
  /ch05Tot   = sum(HH51)
  /ch05Comp  = sum(HH55)
  /ch517All   = sum(HH52)
  /ch517Tot   = sum(HH52A)
  /ch517Comp  = sum(HH56).

* For each region separately.
* Aggregate the hh data file to calculate the sum of sampled, occupied, complete HHs.
* and sum of eligible and interviewed wmTot age 15-49 and children under age 5.
aggregate outfile = 'tmp2.sav'
  /break   = HH7
  /hhSamp  = sum(sampled)
  /hhOccup = sum(occupied)
  /hhComp  = sum(complete)
  /wqSel  = sum(wqSelect)
  /wqhhComp  = sum(wqhhcomplete)
  /wqsoComp  = sum(wqsocomplete)
  /wmTot   = sum(HH49)
  /wmComp  = sum(HH53)
  /mnAll  = sum(HH50A)
  /mnTot   = sum(HH50)
  /mnComp  = sum(HH54)
  /ch05Tot   = sum(HH51)
  /ch05Comp  = sum(HH55)
  /ch517All   = sum(HH52)
  /ch517Tot   = sum(HH52A)
  /ch517Comp  = sum(HH56).

* For overall country.
* Aggregate the hh data file to calculate the sum of sampled, occupied, complete HHs.
* and sum of eligible and interviewed wmTot age 15-49 and children under age 5.
aggregate outfile = 'tmp3.sav'
  /break   = total
  /hhSamp  = sum(sampled)
  /hhOccup = sum(occupied)
  /hhComp  = sum(complete)
  /wqSel  = sum(wqSelect)
  /wqhhComp  = sum(wqhhcomplete)
  /wqsoComp  = sum(wqsocomplete)
  /wmTot   = sum(HH49)
  /wmComp  = sum(HH53)
  /mnAll  = sum(HH50A)
  /mnTot   = sum(HH50)
  /mnComp  = sum(HH54)
  /ch05Tot   = sum(HH51)
  /ch05Comp  = sum(HH55)
  /ch517All   = sum(HH52)
  /ch517Tot   = sum(HH52A)
  /ch517Comp  = sum(HH56).

* Add this summary information together in one data file.
get file = 'tmp1.sav'.
add files
  /file = *
  /file = 'tmp2.sav'
  /file = 'tmp3.sav'.

* Compute response rates for HH, WQ, Women, Men and Under5.
compute hhcr = (hhComp / hhSamp) * 100.
compute hhrr = (hhComp / hhOccup) * 100.
compute wqhhrr = (wqhhComp / wqSel) * 100.
compute wqsorr = (wqsoComp / wqSel) * 100.
compute wmrr = (wmComp / wmTot) * 100.
compute wmor = (hhrr * wmrr) / 100.
compute mnrr = (mnComp / mnTot) * 100.
compute mnor = (hhrr * mnrr) / 100.
compute ch05rr = (ch05Comp / ch05Tot ) * 100.
compute ch05or = (hhrr * ch05rr) / 100.
compute ch517rr = (ch517Comp / ch517Tot ) * 100.
compute ch517or = (hhrr * ch517rr) / 100.

* Compute variables to format the table.
compute hh = 0.
compute wq = 0.
compute wm = 0.
compute mn = 0.
compute ch05 = 0.
compute ch517 = 0.

* Labels in English.
variable labels
   hhSamp        "   Sampled"
  /hhOccup       "   Occupied"
  /hhComp        "   Interviewed"
  /hhcr              "   Household completion rate"
  /hhrr    	     "   Household response rate"
  /wqSel           "   Eligible"
  /wqhhComp    "   Household water quality test: Completed"
  /wqhhrr    	     "   Household water quality test: Response rate"
  /wqsoComp     "   Source water quality test: Completed"
  /wqsorr    	     "   Source water quality test: Response rate"
  /wmTot   	     "    Eligible"
  /wmComp      "    Interviewed"
  /wmrr    	     "    Women's response rate"
  /wmor     	     "    Women's overall response rate"
  /mnAll            "    Number of men in interviewed households"
  /mnTot   	     "    Eligible"
  /mnComp       "    Interviewed"
  /mnrr  	     "    Men's response rate"
  /mnor    	     "    Men's overall response rate"
  /ch05Tot   	     "    Eligible"
  /ch05Comp     "   Mothers/caretakers interviewed "
  /ch05rr    	     "    Under-5's response rate"
  /ch05or   	     "    Under-5's overall response rate"
  /ch517All 	     "    Number of children in interviewed households"
  /ch517Tot 	     "    Eligible"
  /ch517Comp   "    Mothers/caretakers interviewed "
  /ch517rr    	     "    Children age 5-17's response rate"
  /ch517or   	     "    Children age 5-17's overall response rate".

value labels hh 	0 "Households".
value labels wq 	0 "Water quality testing".
value labels wm	0 "Women age 15-49 years".
value labels mn 	0 "Men age 15-49 years".
value labels ch05     	0 "Children under 5 years".
value labels ch517     	0 "Children age 5-17 years".


* Labels in French.
*variable labels
   hhSamp        "   Echantillonnés"
  /hhOccup       "   Occupés"
  /hhComp        "   Enquêtés"
  /hhcr              "   Taux de completitude des ménages "
  /hhrr    	     "   Taux de réponse des ménages"
  /wqSel           "   Test de la qualité de l'Eau -Ménages: Eligible"
  /wqhhComp    "   Test de la qualité de l'Eau -Ménages: Completés"
  /wqhhrr    	     "   Test de la qualité de l'Eau -Ménages: Taux de réponse"
  /wqsoComp     "   Test de la qualité de l'Eau -Source: Completés"
  /wqsorr    	     "   Test de la qualité de l'Eau -Source: Taux de réponse"
  /wmTot   	     "    Eligibles"
  /wmComp      "    Enquêtées"
  /wmrr    	     "    Taux de réponse des femmes"
  /wmor     	     "    Taux de réponse global des femmes"
  /mnAll            "    Nombre des hommes dans les ménages enquetés"
  /mnTot   	     "    Eligibles"
  /mnComp       "    Enquêtés"
  /mnrr  	     "    Taux de réponse des hommes"
  /mnor    	     "    Taux de réponse global des hommes"
  /ch05Tot   	     "    Eligibles"
  /ch05Comp     "   Mères/gardiennes enquêtées"
  /ch05rr    	     "    Taux de réponse des enfants <5 ans"
  /ch05or   	     "    Taux de réponse global des enfants <5 ans"
  /ch517All 	     "    Nombre des enfants dans les ménages enquêtés"
  /ch517Tot 	     "    Eligibles"
  /ch517Comp   "    Mères/gardiennes enquêtées"
  /ch517rr    	     "    Taux de réponse des enfants 5-17 ans"
  /ch517or   	     "    Taux de réponse global des enfants 5-17 ans".

* value labels hh 	0 "Ménages".
* value labels wq 	0 "Test de la qualité de l'Eau".
* value labels wm	0 "Femmes âgées 15-49 ans".
* value labels mn 	0 "Hommes âgés 15-49 ans".
* value labels ch05     	0 "Enfants de moins de 5 ans".
* value labels ch517     	0 "Enfants âgés 5-17 ans".

* Labels in Spanish.
*variable labels
   hhSamp        "   Muestreados"
  /hhOccup       "   Ocupados"
  /hhComp        "   Entrevistados"
  /hhcr              "   Tasa de hogares completados "
  /hhrr    	     "   Tasa de respuesta del hogar"
  /wqSel           "   Prueba de calidad de agua en el hogar : Eligible"
  /wqhhComp    "   Prueba de calidad de agua en el hogar : Completados"
  /wqhhrr    	     "   Prueba de calidad de agua en el hogar : Tasa de respuesta"
  /wqsoComp     "   Prueba de calidad de agua de la fuente: Completados"
  /wqsorr    	     "   Prueba de calidad de agua de la fuente: Tasa de respuesta"
  /wmTot   	     "    Eligibles"
  /wmComp      "    Entrevistados"
  /wmrr    	     "    Tasa de respuesta de las mujeres"
  /wmor     	     "   Tasa global de respuesta de las mujeres"
  /mnAll            "    Número de hombres en hogares entrevistados"
  /mnTot   	     "    Eligibles"
  /mnComp       "       Entrevistados"
  /mnrr  	     "    Tasa de respuesta de los hombres"
  /mnor    	     "    Tasa global de respuesta de los hombres"
  /ch05Tot   	     "    Eligibles"
  /ch05Comp     "   Madres/cuidadoras entrevistadas"
  /ch05rr    	     "    Tasa de respuesta de los menores de 5 "
  /ch05or   	     "    Tasa de respuesta global de menores de 5"
  /ch517All 	     "    Número de niños en hogares entrevistados"
  /ch517Tot 	     "    Eligibles"
  /ch517Comp   "    Madres/cuidadoras entrevistadas"
  /ch517rr    	     "    Tasa de respuest de niños/as de 5-17 años"
  /ch517or   	     "    Tasa de respuesta global de niños/as de 5-17 años".

* value labels hh 	0 "Hogar".
* value labels wq 	0 "Prueba de calidad de agua".
* value labels wm	0 "Mujeres de 15-49 años".
* value labels mn 	0 "Hombres de 15-49 años".
* value labels ch05     	0 "Niños/as menores de 5 años".
* value labels ch517     	0 "Niños/as 5-17 años".


* Ctables command in English (currently active, comment it out if using different language).
ctables
 /format missing=''
 /vlabels variables=total hh wq wm mn ch05 ch517 display=none
 /table hh [c] > (
          	hhSamp [s] [mean '' f5.0] +
          	hhOccup [s] [mean '' f5.0] +
         	hhComp [s] [mean '' f5.0] +
                  hhcr [s] [mean '' f5.1] + 
          	hhrr [s] [mean '' f5.1] 
	     ) +
          wq [c] > (
          	wqSel [s] [mean '' f5.0] +
          	wqhhComp [s] [mean '' f5.0] +
                  wqhhrr [s] [mean '' f5.1] + 
         	wqsoComp [s] [mean '' f5.0] +
          	wqsorr [s] [mean '' f5.1] 
	     ) +
         wm [c] > (
          	wmTot [s] [mean '' f5.0] +
          	wmComp [s] [mean '' f5.0] +
          	wmrr [s] [mean '' f5.1] +
          	wmor [s] [mean '' f5.1] 
	    ) +
         mn [c] > (
                  mnAll [s] [mean '' f5.0] +
         	mnTot [s] [mean '' f5.0] +
          	mnComp [s] [mean '' f5.0] +
         	mnrr [s] [mean '' f5.1] +
          	mnor [s] [mean '' f5.1] 
	    ) +
         ch05 [c] > (
          	ch05Tot  [s] [mean '' f5.0] +
          	ch05Comp [s] [mean '' f5.0] +
         	ch05rr [s] [mean '' f5.1] +
          	ch05or [s] [mean '' f5.1]) +
         ch517 [c] > (
          	ch517All  [s] [mean '' f5.0] +
          	ch517Tot  [s] [mean '' f5.0] +
          	ch517Comp [s] [mean '' f5.0] +
         	ch517rr [s] [mean '' f5.1] +
          	ch517or [s] [mean '' f5.1])
  by
         total [c] +
         hh6 [c] +
         hh7 [c]
 /slabels visible = no
 /categories variables=all empty=exclude missing=exclude
 /titles title=
    "Table SR.1.1: Results of household, household water quality testing, women's, men's, under-5's and children age 5-17's interviews"
    "Number of households, households selected for water quality testing, women, men, children under 5, and children age 5-17 by interview results, according to area of residence and regions, "
    + surveyname
.					


* Ctables command in French (uncomment if producing tables in French).
*ctables
 /format missing=''
 /vlabels variables=total hh wq wm mn ch05 ch517 display=none
 /table hh [c] > (
          	hhSamp [s] [mean '' f5.0] +
          	hhOccup [s] [mean '' f5.0] +
         	hhComp [s] [mean '' f5.0] +
                  hhcr [s] [mean '' f5.1] + 
          	hhrr [s] [mean '' f5.1] 
	     ) +
          wq [c] > (
          	wqSel [s] [mean '' f5.0] +
          	wqhhComp [s] [mean '' f5.0] +
                  wqhhrr [s] [mean '' f5.1] + 
         	wqsoComp [s] [mean '' f5.0] +
          	wqsorr [s] [mean '' f5.1] 
	     ) +
         wm [c] > (
          	wmTot [s] [mean '' f5.0] +
          	wmComp [s] [mean '' f5.0] +
          	wmrr [s] [mean '' f5.1] +
          	wmor [s] [mean '' f5.1] 
	    ) +
         mn [c] > (
                  mnAll [s] [mean '' f5.0] +
         	mnTot [s] [mean '' f5.0] +
          	mnComp [s] [mean '' f5.0] +
         	mnrr [s] [mean '' f5.1] +
          	mnor [s] [mean '' f5.1] 
	    ) +
         ch05 [c] > (
          	ch05Tot  [s] [mean '' f5.0] +
          	ch05Comp [s] [mean '' f5.0] +
         	ch05rr [s] [mean '' f5.1] +
          	ch05or [s] [mean '' f5.1]) +
         ch517 [c] > (
          	ch517All  [s] [mean '' f5.0] +
          	ch517Tot  [s] [mean '' f5.0] +
          	ch517Comp [s] [mean '' f5.0] +
         	ch517rr [s] [mean '' f5.1] +
          	ch517or [s] [mean '' f5.1])
  by
         total [c] +
         hh6 [c] +
         hh7 [c] 
 /slabels visible = no
 /categories variables=all empty=exclude missing=exclude
 /titles title=
    "Table SR.1.1: Results of household, household water quality testing, women's, men's, under-5's and children age 5-17's interviews"
    "Number of households, households selected for water quality testing, women, men, children under 5, and children age 5-17 by interview results, according to area of residence and regions, "
    + surveyname
.						 

* Ctables command in Spanish (uncomment if producing tables in Spanish).
*ctables
 /format missing=''
 /vlabels variables=total hh wq wm mn ch05 ch517 display=none
 /table hh [c] > (
          	hhSamp [s] [mean '' f5.0] +
          	hhOccup [s] [mean '' f5.0] +
         	hhComp [s] [mean '' f5.0] +
                  hhcr [s] [mean '' f5.1] + 
          	hhrr [s] [mean '' f5.1] 
	     ) +
          wq [c] > (
          	wqSel [s] [mean '' f5.0] +
          	wqhhComp [s] [mean '' f5.0] +
                  wqhhrr [s] [mean '' f5.1] + 
         	wqsoComp [s] [mean '' f5.0] +
          	wqsorr [s] [mean '' f5.1] 
	     ) +
         wm [c] > (
          	wmTot [s] [mean '' f5.0] +
          	wmComp [s] [mean '' f5.0] +
          	wmrr [s] [mean '' f5.1] +
          	wmor [s] [mean '' f5.1] 
	    ) +
         mn [c] > (
                  mnAll [s] [mean '' f5.0] +
         	mnTot [s] [mean '' f5.0] +
          	mnComp [s] [mean '' f5.0] +
         	mnrr [s] [mean '' f5.1] +
          	mnor [s] [mean '' f5.1] 
	    ) +
         ch05 [c] > (
          	ch05Tot  [s] [mean '' f5.0] +
          	ch05Comp [s] [mean '' f5.0] +
         	ch05rr [s] [mean '' f5.1] +
          	ch05or [s] [mean '' f5.1]) +
         ch517 [c] > (
          	ch517All  [s] [mean '' f5.0] +
          	ch517Tot  [s] [mean '' f5.0] +
          	ch517Comp [s] [mean '' f5.0] +
         	ch517rr [s] [mean '' f5.1] +
          	ch517or [s] [mean '' f5.1])
  by
         total [c] +
         hh6 [c] +
         hh7 [c] 
 /slabels visible = no
 /categories variables=all empty=exclude missing=exclude
 /titles title=
    "Table SR.1.1: Results of household, household water quality testing, women's, men's, under-5's and children age 5-17's interviews"
    "Number of households, households selected for water quality testing, women, men, children under 5, and children age 5-17 by interview results, according to area of residence and regions, "
    + surveyname.
					
new file.

* Delete temporary working files.
erase file = 'tmp1.sav'.
erase file = 'tmp2.sav'.
erase file = 'tmp3.sav'.