﻿* Encoding: windows-1252.
* MICS6 SR.5.2.

* v01 - 2017-09-21.
* v02 - 2019-08-27. Last modified to reflect tab plan changes as of 25 July 2019.

** Total weighted and unweighted numbers of children under 5 should be equal when normalized sample weights are used.

** The total weighted number of under-5 children does not necessarily match that presented on age group 0-4 years in Table SR.4.1. 
** This table is based on completed under-5 interviews only, whereas Table SR.4.1 is based on completed household interviews. The two tables are computed with different sample weights.


***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'hl.sav'.

sort cases hh1 hh2 hl1.

save outfile='tmp.sav'
  /keep = hh1 hh2 hl1 hl14 
  /rename = (hl1=ln).

* Open children data file.
get file = 'ch.sav'.

* sort cases in order to perform mergeing.
sort cases hh1 hh2 ln.

* merging with tmp file with mother's line number.
match files
 /file=*
 /table='tmp.sav'
 /by hh1 hh2 ln.

recode HL14 (sysmis = 0) (else = copy).
if (HL14 = UF4)  respondentToQ = 1.
if (HL14 ~= UF4) respondentToQ = 2.

variable labels respondentToQ 'Respondent to the under-5 questionnaire'.
value labels respondentToQ
  1 'Mother'
  2 'Other primary caretaker'.

* Select interviewed children.
select if (UF17 = 1).

* Weight the data by the under-5 weight.
weight by chweight.

* In order to add [A] in melevel label.
variable labels melevel "Mother’s education [A]".

* In order to add [B] in disability status.
variable labels cdisability "Functional difficulties (age 2-4 years) [B] [C]".

* In order to add [C] in disability status of caretaker.
variable labels caretakerdis "Mother's functional difficulties [D]".

*Change the labels on the disaggregate of “Health insurance” have been changed to “Has coverage” and “Has no coverage”.
add value labels cinsurance 
 1 "Has coverage"
 2 "Has no coverage" 
 9 "Missing/DK".

compute total = 1.
variable labels total "Total".
value labels total 1" ".

compute wp = 0.
variable labels wp " ".
compute numChildren = 0.
variable labels numChildren "Number of under-5 children".

* Labels in French.
 * variable labels melevel "Instruction de la mère [A]".
 * variable labels cdisability "Difficultés fonctionnelles (âgé 2-4 ans) [B] [C]".
 * variable labels caretakerdis "Difficultés fonctionnelles chez les méres [D]".
 * variable labels numChildren "Nombre d'enfants de moins de 5 ans".
 * add value labels cinsurance 
 1 "Has coverage"
 2 "Has no coverage" 
 9 "Missing/DK".

* Labels in Spanish.
 * variable labels cage_6 "Edad en meses".
 * variable labels melevel "Educación de la madre [A]".
 * variable labels cdisability "Dificultades funcionales (2-4 años de edad) [B] [C]".
 * variable labels caretakerdis "Dificultades funcionales de la madre [D]".
 * variable labels numChildren "Número niños/as menores 5".
 * add value labels cinsurance 
 1 "Has coverage"
 2 "Has no coverage" 
 9 "Missing/DK".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = wp display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + cage_6 [c]
        + melevel [c]
        + respondentToQ [c]
        + cinsurance [c]
        + cdisability [c]
        + caretakerdis [c]
        + ethnicity[c]
        + windex5[c]
   by
          wp [s] [colpct.count,'Weighted percent' f5.1]
        + numChildren [s] [count, 'Weighted', f5.0, 
                           ucount, 'Unweighted', f5.0]
  /categories variables=all empty=exclude missing = exclude
  /titles title =
     "Table SR.5.2: Children under 5's background characteristics"
     "Percent and frequency distribution of children under five years of age by selected background characteristics, " + surveyname
   caption =
            "[A] In this table and throughout the report, mother's education refers to educational attainment of mothers as well as caretakers of children under 5, " +
                    "who are the respondents to the under-5 questionnaire if the mother is deceased or is living elsewhere."  		
            "[B] The results of the Child Functioning module are presented in Chapter 11.1."
            "[C] Children age 0-1 years are excluded, as functional difficulties are only collected for age 2-4 years."            	
            "[D] In this table and throughout the report, mother's functional difficulties refers to functional difficulty of mothers as well as caretakers of children under 5 " +
                     "as mentioned in note A. The category of 'No information' applies to mothers or caretakers to whom the Adult Functioning module was not administered, " +
                     "e.g. the mother is below age 18 or above age 49. Please refer to Tables 8.1W and 8.1M for results of the Adult Functioning module.".	

* Ctables command in French.
*
ctables
  /vlabels variables = wp display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + cage_6 [c]
        + melevel [c]
        + respondentToQ [c]
        + cinsurance [c]
        + cdisability [c]
        + caretakerdis [c]
        + ethnicity[c]
        + windex5[c]
   by
          wp [s] [colpct.count,'Pourcentage pondéré' f5.1]
        + numChildren [s] [count, 'Pondéré', f5.0, 
                           ucount, 'Non pondéré', f5.0]
  /categories variables=all empty=exclude missing = exclude
  /titles title =
     "Tableau SR.5.2: Caractéristiques de base des enfants de moins de 5 ans"
     "Distribution en pourcentage et fréquence des enfants de moins de cinq ans selon les caractéristiques de base sélectionnées, " + surveyname
   caption =
            "[A] Dans ce tableau et tout au long du rapport, l'éducation de la mère se réfère au niveau de scolarité des mères ainsi que des gardiennes des enfants de moins de 5 ans, " +
                    "qui sont les répondants au questionnaire des moins de 5 ans si la mère est décédée ou vit ailleurs."  		
            "[B] B Les résultats du module du Fonctionnement de l'enfant sont présentés au chapitre 11.1."
            "[C] Children age 0-1 years are excluded, as functional difficulties are only collected for age 2-4 years."             	
            "[D] Dans ce tableau et tout au long du rapport, les difficultés fonctionnelles de la mère se réfèrent à la difficulté fonctionnelle " +
                     "des mères et des gardiennes des enfants de moins de 5 ans mentionnée dans la note A. La catégorie «Pas d'information» s'applique aux mères ou aux tuteurs. " +
                     "non administré, p.ex. la mère a moins de 18 ans ou plus de 49 ans. Veuillez consulter les tableaux 8.1W et 8.1M pour les résultats du module sur le fonctionnement des adultes.".		
	
* Ctables command in Spanish.
*
ctables
  /vlabels variables = wp display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + cage_6 [c]
        + melevel [c]
        + respondentToQ [c]
        + cinsurance [c]
        + cdisability [c]
        + caretakerdis [c]
        + ethnicity[c]
        + windex5[c]
   by
          wp [s] [colpct.count,'Porcentaje ponderado' f5.1]
        + numChildren [s] [count, 'Ponderado', f5.0, 
                           ucount, 'Sin ponderar', f5.0]
  /categories variables=all empty=exclude missing = exclude
  /titles title =
     "Tabla SR.5.2: Características básicas de niños/as menores de 5 años"
     "Distribución porcentual y frecuencial de niños/as menores de 5 años por características básicas seleccionadas, " + surveyname
   caption =
            "[A] En esta tabla y a través de todo el reporte, la educación de la madre se refiere a los logros en materia educativa de las madres así como las cuidadoras de los niños/as menores de cinco años, " +
                    "quienes son los respondientes del cuestionario de menores de cinco años si la madre ha fallecido o vive fuera del hogar."  		
            "[B] Los resultados del módulo de capacidad funcional se presentan en el Capítulo 11.1."	
            "[C] Children age 0-1 years are excluded, as functional difficulties are only collected for age 2-4 years."             
            "[D]  Los niños de 0-1 años se excluyen ya que las dificultades funcionales se recolectan sólo para las edades de 2-4 años."
			"[D]  En esta tabla y en todo el informen, las dificultades funcionales de la madre se refieren a las dificultades funcionales de la madre así como a los cuidadores de los niños menores de 5 años como se menciona en la nota A. " + 
			"La categoría «Sin información» aplica a las madres o cuidadores a las cuales no se les pudo administrar el módulo de Funcionamiento en adultos, es decir. la madre es menor de 18 o mayor de 49 años. " + 
			"Consulte en las Tablas 8.1W y 8.1M los resultados del módulo de Funcionamiento en Adultos.".		
		
new file.

erase file = 'tmp.sav'.
