﻿* Encoding: windows-1252.
* MICS6 SR.9.4M.

* v01 - 2017-11-07.
* v01 - 2019-03-14.

** This table shows the results of the 9 individual ICT skills asked in HC10. The last column is computed as at least one yes to any of the 9 skills. The table is based on the full denominator of all men age 15-49.

***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open men dataset.
get file = 'mn.sav'.

include "CommonVarsMN.sps".

* Select completed interviews.
select if (MWM17 = 1).

* Weight the data by the women weight.
weight by mnweight.

* Generate numWomen variable.
compute numMen = 1.
variable labels numMen "".
value labels numMen 1 "Number of men".

* Generate indicators.
recode MMT6A (1 = 100) (else = 0) into copied.
variable labels copied "Copied or moved a file or folder".

recode MMT6B (1 = 100) (else = 0) into filecopy.
variable labels filecopy "Used a copy and paste tool to duplicate or move information within a document".

recode MMT6C (1 = 100) (else = 0) into email.
variable labels email "Sent e-mail with attached file, such as a document, picture or video".

recode MMT6D (1 = 100) (else = 0) into formula.
variable labels formula "Used a basic arithmetic formula in a spreadsheet".

recode MMT6E (1 = 100) (else = 0) into install.
variable labels install "Connected and installed a new device, such as a modem, camera or printer".

recode MMT6F (1 = 100) (else = 0) into software.
variable labels software "Found, downloaded, installed and configured software".

recode MMT6G (1 = 100) (else = 0) into presentation.
variable labels presentation "Created an electronic presentation with presentation software, including text, images, sound, video or charts".

recode MMT6H (1 = 100) (else = 0) into transfer.
variable labels transfer "Transfered a file between a computer and other device".

recode MMT6I (1 = 100) (else = 0) into code.
variable labels code "Wrote a computer program in any programming language".

compute atLeastOne = 0.
if (copied = 100 or filecopy = 100 or email = 100 or formula = 100 or install = 100 or software = 100 or presentation = 100 or transfer = 100 or code = 100) atLeastOne = 100.
variable labels atLeastOne "Performed at least one of the nine listed computer related activities [1] [2]".

compute layer0 = 0.
variable labels layer0 "".
value labels layer0 0 "Percentage of men who in the last 3 months:".

compute total = 1.
variable labels total "".
value labels total 1 "Total".

*  For labels in French uncomment commands below.
* variable labels 
     copied "Copié ou déplacé un fichier ou un dossier"
	/filecopy "Utilisé un outil de copier-coller pour dupliquer ou déplacer des informations dans un document"
	/email "Envoyé un e-mail avec un fichier joint, tel qu'un document, une photo ou une vidéo"
	/formula "Utiliser une formule arithmétique de base dans une feuille de calcul"
	/install "Connecté et installé un nouveau dispositif, tel qu'un modem, un appareil photo ou une imprimante"
	/software "Logiciel trouvé, téléchargé, installé et configuré"
	/presentation "Créer une présentation électronique avec un logiciel de présentation, y compris du texte, des images, du son, des vidéos ou des graphiques"
	/transfer "Transféré un fichier entre un ordinateur et un autre dispositif"
	/code "A écrit un programme informatique dans un langage de programmation"
	/atLeastOne "A exécuté au moins une des neuf activités liées à l'informatique énumérées [1]".
* value labels 
     numMen 1 "Nombre d'hommes âgés de 15-49 ans"
	/layer0 0 "Pourcentage d'hommes âgés de 15-49 ans qui, dans les 3 derniers mois:".
	
*  For labels in Spanish uncomment commands below.
* variable labels 
     copied "Copiado o movido un archivo o carpeta"
	/filecopy "Usado una herramienta de copiar y pegar para duplicar o mover información dentro de un documento"
	/email "Enviado un correo electrónico con un archivo adjunto, como un documento, foto o video"
	/formula "Usado una fórmula básica aritmética en una hoja de cálculo"
	/install "Conectado e instalado un dispositivo nuevo, como un modem, una cámara,  o una impresora"
	/software "Buscado, descargad o instalado y configurado  programas"
	/presentation "Creado una presentación electrónica con un programa para ese fin, incluyendo texto, imágenes, sonido, video o gráfico"
	/transfer "Transferido un archivo entre una computadora y otro dispositivo"
	/code "Escrito un programa de computación en cualquier lenguaje de programación"
	/atLeastOne "Realizado al menos una de las nueve actividades en computación [1]".
* value labels 
     numMen 1 "Número de hombres de 15-49 años"
	/layer0 0 "Porcentaje de hombres de 15-49 años que en los últimos 3 meses han:".


ctables
  /vlabels variables =  numMen layer0 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $mwagew [c]
        + mwelevel [c]
        + mdisability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( copied [s] [mean '' f5.1]
                        + filecopy [s] [mean '' f5.1]
                        + email [s] [mean '' f5.1]
                        + formula [s] [mean '' f5.1]
                        + install [s] [mean '' f5.1]
                        + software [s] [mean '' f5.1]
                        + presentation [s] [mean '' f5.1]
                        + transfer [s] [mean '' f5.1]
                        + code [s] [mean '' f5.1]
                        + atLeastOne [s] [mean '' f5.1] )
            + numMen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table SR.9.4M: ICT skills (men)"
     "Percentage of men age 15-49 years who in the last 3 months have carried out computer related activities, " 
     + surveyname
   caption =
        "[1] MICS indicator SR.13a - ICT skills (age 15-24 years); SDG indicator 4.4.1"
        "[2] MICS indicator SR.13b - ICT skills (age 15-49 years); SDG indicator 4.4.1"	
.								

* Ctables command in French.  
* ctables
  /vlabels variables =  numMen layer0 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
      + $mwagew [c]
        + mwelevel [c]
        + mdisability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( copied [s] [mean '' f5.1]
                        + filecopy [s] [mean '' f5.1]
                        + email [s] [mean '' f5.1]
                        + formula [s] [mean '' f5.1]
                        + install [s] [mean '' f5.1]
                        + software [s] [mean '' f5.1]
                        + presentation [s] [mean '' f5.1]
                        + transfer [s] [mean '' f5.1]
                        + code [s] [mean '' f5.1]
                        + atLeastOne [s] [mean '' f5.1] )
            + numMen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau SR.9.4M: Compétences en TIC (hommes)"
     "Pourcentage des hommes âgés de 15 à 49 ans qui, au cours des trois derniers mois, ont mené des activités liées à l'informatique, " 
     + surveyname
   caption =
        "[1] MICS indicator SR.13a - ICT skills (age 15-24 years); SDG indicator 4.4.1"
        "[2] MICS indicator SR.13b - ICT skills (age 15-49 years); SDG indicator 4.4.1"	
.

* Ctables command in Spanish.  
* ctables
  /vlabels variables =  numMen layer0 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
      + $mwagew [c]
        + mwelevel [c]
        + mdisability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( copied [s] [mean '' f5.1]
                        + filecopy [s] [mean '' f5.1]
                        + email [s] [mean '' f5.1]
                        + formula [s] [mean '' f5.1]
                        + install [s] [mean '' f5.1]
                        + software [s] [mean '' f5.1]
                        + presentation [s] [mean '' f5.1]
                        + transfer [s] [mean '' f5.1]
                        + code [s] [mean '' f5.1]
                        + atLeastOne [s] [mean '' f5.1] )
            + numMen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla SR.9.4M: Habilidades TIC (hombres)"
     "Porcentaje de hombres de 15-49 años que han realizado actividades en computación en los últimos 3 meses, " 
     + surveyname
   caption =
        "[1] MICS indicator SR.13a - ICT skills (age 15-24 years); SDG indicator 4.4.1"
        "[2] MICS indicator SR.13b - ICT skills (age 15-49 years); SDG indicator 4.4.1"	
.
new file.
