* Encoding: windows-1252.
* MICS6 TM1.1&TM2.1.

* The age-specific fertility rate is defined as the number of live births to women in a specific age group during a specified period, 
divided by the average number of women in that age group during the same period, expressed per 1,000 women. The age-specific fertility rate for women age 15-19 years is also termed as the adolescent birth rate.

* The total fertility rate (TFR) is calculated by summing the age-specific fertility rates calculated for each of the 5-year age groups of women, 
from age 15 through to age 49. The TFR denotes the average number of children to which a woman will have given birth by the end of her reproductive years (by age 50) if current fertility rates prevailed.

* The general fertility rate (GFR) is the number of live births to women age 15-49 years during a specified period, divided by the average number of women in the same age group during the same period, expressed per 1,000 women.

* The crude birth rate (CBR) is the number of live births during a specified period, divided by the total population during the same period, expressed per 1,000 population.

* Rates are calculated for the three-year (1-36 months) period preceding the survey, based on data collected in birth histories. The month of interview is ignored, as it would represent a censored (incomplete) period of observation.

* See notes below TM.2.1 for further details.

***.
include "surveyname.sps".

* Main program - calls.
*  MICS6 - 06 - fert_b.sps  for calculation of births.
*  MICS6 - 06 - fert_e.sps  for calculation of exposure.
*  MICS6 - 06 - fert_p.sps  for calculation of live births during a specified period, divided by the total population during the same period,.
*  MICS6 - 06 - fert_c.sps  for calculation of probabilities and rates, and final tables.

define runfert (backvar = !tokens(1) / backval = !tokens(1)).
get file='bh.sav'.
!if (!backvar=total) !then
compute !backvar=!backval.
execute.
!ifend
select if (!backvar=!backval).
compute period=36.
compute maxper=5.
include 'MICS6 - 06 - fert_B.sps'.
get file='wm.sav'.
!if (!backvar=total) !then
compute !backvar=!backval.
execute.
!ifend
select if (WM17 = 1 and !backvar=!backval).
compute period=36.
compute maxper=5.
include 'MICS6 - 06 - fert_E.sps'.
get file = 'hl.sav'.
!if (!backvar=total) !then
compute !backvar=!backval.
execute.
!ifend
!if (!backvar=welevel) !then
compute !backvar=!backval.
execute.
!ifend
select if (!backvar=!backval).
include 'MICS6 - 06 - fert_P.sps'.
include 'MICS6 - 06 - fert_C.sps'.
compute !backvar=!backval.
!if (!backvar<>total) !then
add files
  /file='tmpfert.sav'
  /file=*.
execute.
!ifend
save outfile='tmpfert.sav'.
new file.
erase file = 'births.sav'.
erase file = 'exposure.sav'.
erase file = 'exposuretotal.sav'.
!enddefine.

* National fertility estimates.
define subgroupname ()
'(Total)'
!enddefine.
runfert backvar=total backval=1.

* Regions.
define subgroupname ()
'(Region 1)'
!enddefine.
runfert backvar=hh7 backval=1.

define subgroupname ()
'(Region 2)'
!enddefine.
runfert backvar=hh7 backval=2.

define subgroupname ()
'(Region 3)'
!enddefine.
runfert backvar=hh7 backval=3.

define subgroupname ()
'(Region 4)'
!enddefine.
runfert backvar=hh7 backval=4.

define subgroupname ()
'(Region 5)'
!enddefine.
runfert backvar=hh7 backval=5.


* Ethnicity.
define subgroupname ()
'(Group 1)'
!enddefine.
runfert backvar=ethnicity backval=1.

* Ethnicity.
define subgroupname ()
'(Group 2)'
!enddefine.
runfert backvar=ethnicity backval=2.

* Ethnicity.
define subgroupname ()
'(Group 3)'
!enddefine.
runfert backvar=ethnicity backval=3.

* Ethnicity.
define subgroupname ()
'(Other)'
!enddefine.
runfert backvar=ethnicity backval=6.


* Area.
define subgroupname ()
'(Urban)'
!enddefine.
runfert backvar=HH6 backval=1.

define subgroupname ()
'(Rural)'
!enddefine.
runfert backvar=HH6 backval=2.


* Mother's education.
define subgroupname ()
'(Pre-primary or none)'
!enddefine.
runfert backvar=welevel backval=0.

define subgroupname ()
'(Primary)'
!enddefine.
runfert backvar=welevel backval=1.

define subgroupname ()
'(Lower secondary)'
!enddefine.
runfert backvar=welevel backval=2.

define subgroupname ()
'(Upper secondary +)'
!enddefine.
runfert backvar=welevel backval=3.


define subgroupname ()
'(Has functional difficulty)'
!enddefine.
runfert backvar=disability backval=1.

define subgroupname ()
'(Has no functional difficulty)'
!enddefine.
runfert backvar=disability backval=2.


* Wealth index quintile.
define subgroupname ()
'(Poorest)'
!enddefine.
runfert backvar=windex5 backval=1.

define subgroupname ()
'(Second)'
!enddefine.
runfert backvar=windex5 backval=2.

define subgroupname ()
'(Middle)'
!enddefine.
runfert backvar=windex5 backval=3.

define subgroupname ()
'(Fourth)'
!enddefine.
runfert backvar=windex5 backval=4.

define subgroupname ()
'(Richest)'
!enddefine.
runfert backvar=windex5 backval=5.


* Produce final output tables.

get file='tmpfert.sav'.

variable labels hh7 'Region'.
variable labels hh6 'Area'.
variable labels welevel "Education".
variable labels disability "Functional difficulties (age 18-49 years)".
variable labels windex5 'Wealth index quintiles'.
variable labels ethnicity 'Ethnicity of household head'.
variable labels total 'Total'.

value labels hh7 1 'Region 1' 2 'Region 2' 3 'Region 3' 4 'Region 4' 5 'Region 5'.
value labels hh6 1 'Urban' 2 'Rural'.
value labels welevel 0 'Pre-primary or none' 1 'Primary' 2 'Lower secondary ' 3 'Upper secondary +'.
value labels disability 1 'Has functional difficulty' 2 'Has no functional difficulty'.
value labels windex5 1 'Poorest' 2 'Second' 3 "Middle" 4 "Fourth" 5 "Richest".
value labels ethnicity 1 "Group 1" 2 "Group 2" 3 "Group 3" 6 "Other".
value labels total 1 ' '.

add value labels age5 1 "15-19 [1]".

use all.
compute sel = (colper = 0).
filter by sel.

*  For labels in French uncomment commands below.
* variable labels 
    hh7 'Rgion'
   /hh6 'Milieu de rsidence'
   /welevel "Instruction"
   /disability "Difficults fonctionnelles (ge 18-49 years)"
   /windex5 'Indice de bien-tre conomique'
   /ethnicity 'Ethnie du chef de mnage'.
* value labels hh7 1 'Rgion 1' 2 'Rgion 2' 3 'Rgion 3' 4 'Rgion 4' 5 'Rgion 5'
* value labels hh6 1 'Urbain' 2 'Rural'.
* value labels welevel 0 'Pre primaire ou nant' 1 'Primaire' 2 'Secondaire I' 3 'Secondaire II et plus'.
* value labels disability 1 'A une difficult fonctionnelle' 2 'Pas de difficults fonctionnelle'.
* value labels windex5 1 'Le plus pauvre' 2 'Second' 3 "Moyen" 4 "Quatrime" 5 "Le plus riche".
* value labels ethnicity 1 "Group 1" 2 "Group 2" 3 "Group 3" 6 "Other".  

*  For labels in Spanish uncomment commands below.
* variable labels 
    hh7 'Regin'
   /hh6 'rea'
   /welevel "Educacin"
   /disability "Dificultades funcionales (18-49 aos de edad)"
   /windex5 'Quintiles de ndice de riqueza'
   /ethnicity 'Etnia del jefe del hogar'.
* value labels hh7 1 'Regin 1' 2 'Regin 2' 3 'Regin 3' 4 'Regin 4' 5 'Regin 5'.
* value labels hh6 1 'Urbana' 2 'Rural'.
* value labels welevel 0 'Pre-primaria o ninguna' 1 'Primaria ' 2 'Secundaria I' 3 'Secundaria II +'.
* value labels disability 1 'Con dificultades funcionales' 2 'Sin dificultades funcionales'.
* value labels windex5 1 'Ms pobre' 2 'Segundo' 3 "Medio" 4 "Cuarto" 5 "Ms rico".
* value labels ethnicity 1 "Group 1" 2 "Group 2" 3 "Group 3" 6 "Other".

ctables
  /vlabels variables=age5 asfr display = none
  /table asfr[s][mean '' comma5.0]>age5[c]+tfr[s][maximum '' f5.1]+gfr[s][maximum '' f5.1]+cbr[s][sum '' f5.1] by hh6[c] + total[c]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=row
  /titles title = "Table TM.1.1: Fertility rates"
                    "Adolescent birth rate, age-specific and total fertility rates, the general fertility rate, and the crude birth rate for the three-year period preceding the survey, by area, " + surveyname
   caption =  "[1] MICS indicator TM.1 - Adolescent birth rate (age 15-19 years); SDG indicator 3.7.2"			
    "[A] The age-specific fertility rates (ASFR) are the number of live births in the last 3 years, divided by the average number of women in that age group during the same period, expressed per 1,000 women."			
    "[B] TFR: The Total Fertility Rate is the sum of age-specific fertility rates of women age 15-49 years. "+
    "The TFR denotes the average number of children to which a woman will have given birth by the end of her reproductive years (by age 50) if current fertility rates prevailed. The rate is expressed per woman age 15-49 years"		
    "[C] GFR: The General Fertility Rate is the number of births in the last 3 years divided by the average number of women age 15-49 years during the same period, expressed per 1,000 women age 15-49 years"
    "[D] CBR: The Crude Birth Rate is the number of births in the last 3 years, divided by the total population during the same period, expressed per 1,000 population"
   corner = "Age [A]".		

* Ctables command in French.  
* ctables
  /vlabels variables=age5 asfr display = none
  /table asfr[s][mean '' comma5.0]>age5[c]+tfr[s][maximum '' f5.1]+gfr[s][maximum '' f5.1]+cbr[s][sum '' f5.1] by hh6[c] + total[c]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=row
  /titles title = "Tableau TM.1.1: Taux de fcondit"
                    "Taux de natalit des adolescentes et taux spcifique par ge et indice synthtique de fcondit, taux global de fcondit et taux brut de natalit pour la priode de un/trois ans prcdant l'enqute selon le milieu de rsidence," + surveyname																																								   
   caption =  "[1] Indicateur MICS TM.1 - Taux de natalit des adolescentes (age 15-19 ans); Indicator ODD 3.7.2"			
    "[A] Les taux de fcondit par ge  sont le nombre de naissances vivantes au cours des 3 dernires annes, divis par le nombre moyen de femmes dans ce groupe d'ge au cours de la mme priode, exprim par 1 000"			
    "[B] ISF: Le taux de fcondit total est la somme des taux de fcondit par ge des femmes de 15  49 ans. "+
    " L'ISF indique le nombre moyen d'enfants auxquels une femme aura accouch  la fin de ses annes de procration ( 50 ans) si les taux de fcondit actuels prvalent. Le taux est exprim par femme de 15  49 ans"		
    "[C] TFG: Le taux gnral de fcondit est le nombre de naissances au cours des 3 dernires annes divis par le nombre moyen de femmes ges de 15  49 ans au cours de la mme priode, exprim par 1 000 femmes "
    "[D] TBN: Le taux de natalit brut est le nombre de naissances au cours des 3 dernires annes, divis par la population totale au cours de la mme priode, exprim par 1 000 habitants"
  corner = "Age [A]".	

* Ctables command in Spanish.  
* ctables
  /vlabels variables=age5 asfr display = none
  /table asfr[s][mean '' comma5.0]>age5[c]+tfr[s][maximum '' f5.1]+gfr[s][maximum '' f5.1]+cbr[s][sum '' f5.1] by hh6[c] + total[c]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=row
  /titles title = "Tabla TM.1.1: Tasas de fecundidad"
                    "Tasa de natalidad de adolescentes, tasa total de fecundidad y especfica por edad,  tasa general de fecundidad, y la tasa bruta de natalidad para el periodo de tres aos anteriores a la encuesta, por rea," + surveyname
   caption =  "[1] Indicador MICS TM.1 - Tasa de natalidad adolescente (15-19 aos); indicador ODS 3.7.2"			
    "[A] Las tasas especficas por edad de fecundidad (ASFR siglas en ingls) son el nmero de nacidos vivos en los ltimos 3 aos, dividido por el nmero medio de mujeres en ese grupo de edad en el mismo perodo, expresado por 1 000 mujeres La tasa de fecundidad especfica por edad para las mujeres de 15-19 aos tambin se denomina como tasa de natalidad adolescente"			
    "[B] TFR: La tasa global de fecundidad (TFR siglas en ingls) es la suma de las tasas de fecundidad por edad de las mujeres de 15-49 aos. "+
    "La tasa global de fecundidad indica el nmero medio de hijos a la que una mujer habr dado a luz al final de sus aos reproductivos (de 50 aos) si las tasas de fecundidad actuales prevalecieran. Se expresa por mujeres de 15-49 aos"		
    "[C] GFR: La tasa de fecundidad general  (GFR siglas en ingls) es el nmero de nacidos vivos de las mujeres de edad 15 a 49 aos durantelos ltimos 3 aos, dividido por el nmero promedio de mujeres en el mismo grupo de edad durante el mismo perodo, expresadas por cada 1 000 mujeres"
    "[D] GFR: La tasa de fecundidad general  (GFR siglas en ingls) es el nmero de nacidos vivos de las mujeres de edad 15 a 49 aos durantelos ltimos 3 aos, dividido por el nmero promedio de mujeres en el mismo grupo de edad durante el mismo perodo, expresadas por cada 1 000 mujeres"
  corner = "Edad [A]".	
   
use all.
if (age5=1) asfr1519 = asfr.
if (age5<>1) asfr1519 = lag(asfr1519).
variable labels asfr1519 'Adolescent birth rate [1] (Age-specific fertility rate for women age 15-19 years) [A]'.
compute sel = (colper = 0 and age5 = 7).
filter by sel.

*  For labels in French uncomment commands below.
* variable labels asfr1519 'Taux de natalit des adolescentes [1] (taux de fcondit par ge spcifique pour les femmes de 15-19 ans) [A]'.

*  For labels in Spanish uncomment commands below.
* variable labels asfr1519 'Tasa de natalidad de adolescente [1] (tasas de fecundidad por edad especfica para mujeres de 15-19 aos) [A]'.

ctables
   /table  total[c] + hh6[c] + hh7[c] + welevel [c] + disability [c] + ethnicity[c] + windex5[c]  BY
      asfr1519[s][mean '' comma5.0]+tfr[s][maximum '' f5.1]
   /categories variables=all empty=exclude missing=exclude
   /titles
    title=
    "Table TM.2.1: Adolescent birth rate and total fertility rate"
    "Adolescent birth rates and total fertility rates for the one-year / three-year period preceding the survey, "+ surveyname
    caption=
    "[1] MICS indicator TM.1 - Adolescent birth rate (age 15-19 years);SDG indicator 3.7.2"
    "[A] Please see Table TM.1.1 for definitions.".


* Ctables command in French.  
* ctables
   /table  total[c] + hh6[c] + hh7[c] + welevel [c] + disability [c] + ethnicity[c] + windex5[c]  BY
      asfr1519[s][mean '' comma5.0]+tfr[s][maximum '' f5.1]
   /categories variables=all empty=exclude missing=exclude
   /titles
    title=
    "Tableau TM.2.1: Taux de natalit des adolescentes et Indice Synthtique de Fcondit"
    "Taux de natalit des adolescentes et Indice Synthtique de Fcondit pour les priodes de un an/trois ans prcdant l'enqute, "+ surveyname
    caption=
    "[1] Indicateur MICS TM.1 - Taux de natalit des adolescentes (ge 15-19 ans); Indicateur ODD 3.7.2"
    "[A] Veuillez consulter le tableau TM.1.1 pour les dfinitions.".

* Ctables command in Spanish.  
* ctables
   /table  total[c] + hh6[c] + hh7[c] + welevel [c] + disability [c] + ethnicity[c] + windex5[c]  BY
      asfr1519[s][mean '' comma5.0]+tfr[s][maximum '' f5.1]
   /categories variables=all empty=exclude missing=exclude
   /titles
    title=
    "Tabla TM.2.1: Tasa de natalidad adolescente y tasa total de fecundidad"
    "Tasa de natalidad adolescente y tasas totales de fecundidad el periodo de tres aos anteriores a la encuesta, "+ surveyname
    caption=
    "[1] Indicador MICS TM.1 - Tasa de natalidad adolescente (15-19 aos); indicador ODS 3.7.2"
    "[A] Ver las definiciones en la Tabla TM.1.1".

new file.

*erase the working files.
erase file = 'tmpfert.sav'.
