* Encoding: windows-1252.
* Call include file for the working directory and the survey name.

*v2. 2019-03-14.

include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

* select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

compute layerW = 0.
variable labels layerW "".
value labels layerW 0 "Percentage of live births weighed at birth:".

compute fromCard = 0.
if (MN34A = 1) fromCard = 100.
variable labels fromCard "From card".

compute fromRecall = 0.
if (MN34A = 2) fromRecall = 100.
variable labels fromRecall "From recall".

compute totalWeighted = 0.
if (MN33 = 1) totalWeighted = 100.
variable labels totalWeighted "Total [1] [A]".

do if (MN34 < 9.997).
+ compute numWeighted = 1.
end if.

do if (numWeighted = 1).

compute lessThen2500Card = 0.
if (MN34A = 1 and MN34 < 2.5) lessThen2500Card = 100.
variable labels lessThen2500Card "From card".

compute lessThen2500Recall = 0.
if (MN34A = 2 and MN34 < 2.5) lessThen2500Recall = 100.
variable labels lessThen2500Recall "From recall".

compute lessThen2500= 0.
if (MN34 < 2.5) lessThen2500 = 100.
variable labels lessThen2500 "Total".

end if.

compute layer2500 = 0.
variable labels layer2500 "".
value labels layer2500 0 "Percentage of weighed live births recorded below 2,500 grams (crude low birth-weight) [B]:".

* generate total variable.
compute total = 1.
variable labels total "".
value labels total 1 "Total".

compute total100 = 100.
variable labels total100 "Total".

compute  numChildren = 1.
variable labels numChildren ''.
value labels numChildren 1 'Number of women with a live birth in the last 2 years'.

variable labels numWeighted ''.
value labels numWeighted 1 'Number of women with a live birth in the last 2 years whose most recent live-born child have a recorded or recalled birthweight'.

* generate order of the birth by looking at the total number of children ever born. 
recode cm11
  (1=1)
  (2,3 = 2)
  (4,5 = 4)
  (6 thru highest = 6)
  into birthOrder.
variable labels birthOrder "Birth order of most recent live birth".
value labels birthOrder
 1 '1'
 2 '2-3'
 4 '4-5'
 6 '6+' .

variable labels welevel "Education".

variable labels ageAtBirth "Mothers age at delivery".
variable labels disability "Functional difficulties (age 18-49 years)".

* For labels in French uncomment commands below.
* variable labels
  fromCard "De la carte"
 /fromRecall "De rappel"
 /lessThen2500Card "De la carte"
 /lessThen2500Recall "De rappel"
 /birthOrder "Rang de naissance"
 /welevel "Instruction de la mre"
 /ageAtBirth "Mothers age at delivery"
 /disability "Mother's functional disabilities (age 18-49 years)".
* value labels 
   layer2500 0 "Pourcentage de naissances vivantes peses enregistres en dessous de 2 500 grammes (poids insuffisant  la naissance) [B]:"
  /numChildren 1 'Nombre de derniers enfants ns vivants au cours des deux dernires annes'
  /numWeighted 1 'Nombre de derniers enfants ns vivants au cours des deux dernires annes avec un poids de naissance enregistr ou rappel'
  /layer 1 'Pourcentage de nouveuax ns pess  la naissance:'.
  
* For labels in Spanish uncomment commands below.
* variable labels
  fromCard "De la tarjeta"
 /fromRecall "Por declaracin"
 /lessThen2500Card "De la tarjeta"
 /lessThen2500Recall "Por declaracin"
 /birthOrder "Orden de nacimiento"
 /welevel "Educacin de la madre"
 /ageAtBirth "Mothers age at delivery"
 /disability "Mother's functional disabilities (age 18-49 years)".
* value labels 
   layer2500 0 "Porcentaje de nacidos vivos pesados con registro de menos de 2,500 gramos (bajo peso crudo) [B]:"
  /numChildren 1 'Nmero de ltimos nacidos vivos en los ltimos 2 aos'
  /numWeighted 1 'Nmero de ltimos nacidos vivos en los ltimos 2 aos con peso al nacer registrado o declarado'
  /layer 1 'Percentage of live births:'.

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables=total layerW layer2500 numChildren numWeighted display=none
  /table  total [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]         
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + birthOrder [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]  
   by
         layerW [c] > (fromCard [s][mean f8.1] + fromRecall [s][mean f8.1] + totalWeighted [s][mean f8.1]) + numChildren [c][count] + 
         layer2500 [c] >  (lessThen2500Card [s][mean f8.1] + lessThen2500Recall [s][mean f8.1] + lessThen2500 [s][mean f8.1]) + numWeighted [c][count]
  /slabels visible = no
  /titles title=
     "Table TM.7.1: Infants weighed at birth"
     "Percentage of women age 15-49 years with a live birth in the last 2 years whose most recent live-born child was weighed at birth, " +
     "by source of information, and percentage of those with a recorded or recalled birthweight estimated to have weighed below 2,500 grams at birth, " +
     "by source of information, " + surveyname
   caption =
     "[1] MICS indicator TM.11 - Infants weighed at birth"
     "[A] The indicator includes children that were reported weighed at birth, but with no actual birthweight recorded or recalled	"						
     "[B] The values here are as recorded on card or as reported by respondent. The total crude low birth-weight typically requires adjustment for heaping, " +
     "particularly at exactly 2,500 gram. The results presented here cannot be considered to represent the precise rate of low birth-weight (very likely an underestimate) " +
     "and therefore not reported as a MICS indicator. More note coming later on old and new model and future of inclusion of indicator in MICS".						

* Ctables command in French.
* ctables
  /vlabels variables=total layerW layer2500 numChildren numWeighted display=none
  /table  total [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]         
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + birthOrder [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]  
   by
         layerW [c] > (fromCard [s][mean f8.1] + fromRecall [s][mean f8.1] + totalWeighted [s][mean f8.1]) + numChildren [c][count] + 
         layer2500 [c] >  (lessThen2500Card [s][mean f8.1] + lessThen2500Recall [s][mean f8.1] + lessThen2500 [s][mean f8.1]) + numWeighted [c][count]
  /slabels visible = no
  /titles title=
     "Tableau TM.7.1: Enfants pess  la naissance"
     "Pourcentage des derniers enfants ns vivants au cours des deux dernires annes pess  la naissance, selon la source d'information, " +
     "et pourcentage de ceux pess  la naissance estims avoir pes moins de 2 500 grammes  la naissance, selon la source d'information,  " + surveyname
   caption =
     "[1] Indicateur MICS TM.11 - Enfants pess  la naissance"
     "[A] L'indicateur inclut les enfants qui ont t dclars pess  la naissance, mais sans poids de naissance rel enregistr ou rappel"						
     "[B] Les valeurs ici sont enregistres sur la carte ou signales par le rpondant. Le poids brut total  la naissance doit gnralement tre ajust pour tre entass, "+
     "en particulier  exactement 2 500 grammes. Les rsultats prsents ici ne peuvent pas tre considrs comme reprsentant le taux prcis de faible poids  la naissance (trs probablement une sous-estimation) et " +
     "ne sont donc pas rapports en tant qu'indicateur MICS. Plus de note  venir plus tard sur l'ancien et le nouveau modle et l'avenir de l'inclusion de l'indicateur dans les MICS".						


* Ctables command in Spanish.
* ctables
  /vlabels variables=total layerW layer2500 numChildren numWeighted display=none
  /table  total [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]         
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + birthOrder [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]  
   by
         layerW [c] > (fromCard [s][mean f8.1] + fromRecall [s][mean f8.1] + totalWeighted [s][mean f8.1]) + numChildren [c][count] + 
         layer2500 [c] >  (lessThen2500Card [s][mean f8.1] + lessThen2500Recall [s][mean f8.1] + lessThen2500 [s][mean f8.1]) + numWeighted [c][count]
  /slabels visible = no
  /titles title=
     "Tabla TM.7.1: Nios pesados al nacer"
     "Porcentaje de los ltimos nacidos vivos en los los ltimos dos aos pesados al nacer, segn fuente de informacin y porcentaje para los que se estim que pesaron menos de 2,500 gramos al nacer, por fuente de informacin,  " + surveyname
   caption =
     "[1] Indicador MICS TM.11 - Nios/as pesados al nacer"
     "[A] El indicador incluye a que se reportaron como pesados al nacer pero sobre los que no se obtuvo el peso al nacer del registro o por declaracin"						
     "[B] Los valores aqui son los registrado en la tarjeta o los declarados por la entrevistada. El bajo peso total crudo tipicamente requiere ajustes para los pesos al nacer ignorados as como por los amontonamientos o redondeos, "+
     "especialmente en los 2,500 gramos exactos. Estos resultados no pueden ser considerados como una representacin precisa de la tasa de bajo peso al nacer (muy probablemente subestima el valor) y " +
     "en consecuencia no se reporta como un indicador MICS.".						

new file.