* Encoding: windows-1252.
 * "Children who were dried after birth are those responding 'yes' to MN26 (MN26=1).

 * Those given skin-to-skin contact are those that were placed on the mother's bare skin of the chest and were not wrapped up (MN23=1 and MN24=2).

 * The timing of first bath is distributed between those that were bathed within 6 hours (MN26=000 or MN26<106), those bathed at 6-23 hours (MN26>105 and <123) and 
   those bathed after their first day of life (MN26>201 and <997). Those never bathed (did not live long enough to be bathed) and those for whom the mother does not know or 
   remember are MN26=997 and MN26=998, respectively."										

***.
*v2. 2019-03-14.

include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

*select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

include 'define\MICS6 - 06 - TM.sps' .

compute driedatbirth=0.
if (MN25 = 1) driedatbirth=100.
variable labels driedatbirth "Dried (wiped) after birth [1]".

compute skintoskin=0.
if (MN23 = 1 and MN24 = 2) skintoskin=100.
variable labels skintoskin "Given skin-to-skin contact with mother [2]".

compute MN26hours=MN26U*100+MN26N.

recode MN26hours (0 thru 105=1)  (106 thru 123=2) (124 thru 996=3) (997 = 4) (998 thru highest = 9) into bathtime.
variable labels bathtime "Timing of first bath".  

value labels bathtime 1 "Less than 6 hours after birth" 2 "6-23 hours after birth" 3 "24 hours or more after birth [3]" 4 "Never bathed [A]" 9 "DK/Don't remember".
 
compute layer1 = 0.
variable labels layer1 "".
value labels layer1 0 "Percentage of children who were:".

compute layer2 = 0.
variable labels layer2 "".
value labels layer2 0 "Timing of first bath:".

compute numWomen = 1.
variable labels numWomen "".
value labels numWomen 1 "Number of women with a live birth in the last 2 years".

variable labels welevel "Education".
variable labels ageAtBirth "Age at most recent live birth".
variable labels disability "Functional difficulties (age 18-49 years)".

compute total = 1.
variable labels total "".
value labels total 1 "Total".

* For labels in French uncomment commands below.
* variable labels
     driedatbirth "Sch (essuy) aprs la naissance [1]"
   /skintoskin "Ont reu le contact peau--peau avec la mre [2]"
   /bathtime "Moment du premier bain:"
   /welevel "Mothers education"
   /ageAtBirth "Mothers age at delivery"
   /disability "Mother's functional disabilities (age 18-49 years)".
* value labels 
   /bathtime 
     1 "Moins de 6 heures aprs la naissance" 
	 2 "6-23 heures aprs la naissance" 
	 3 "Plus de 24 heures aprs la naissance [3]" 
	 4 "Jamais baign [A]" 
	 9 "JSP/ Ne me souviens pas"
   /layer1 0 "Pourcentage d'enfants qui taient:"
   /layer2 0 "Moment du premier bain:"
   /numWomen 1 "Nombre total de naissances vivantes dans les 2 dernires annes".

* For labels in Spanish uncomment commands below.
* variable labels
     driedatbirth "Secado (frotado) despus del nacimiento [1]"
   /skintoskin "Dado contacto piel con piel con la madre [2]"
   /bathtime "Momento del primer bao:"
   /welevel "Mothers education"
   /ageAtBirth "Mothers age at delivery"
   /disability "Mother's functional disabilities (age 18-49 years)".
* value labels 
   /bathtime 
     1 "Menos de 6 horas despus del nacimiento" 
	 2 "6-23 horas despus del nacimiento" 
	 3 "Ms de 24 horas despus del nacimiento [3]" 
	 4 "No se ba [A]" 
	 9 "NS/No recuerda"
   /layer1 0 "Porcentaje de nios que fueron:"
   /layer2 0 "Momento del primer bao:"
   /numWomen 1 "Nmero de ltimos nacimientos vivos en los ltimos dos aos".
   
* ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  numWomen layer1 layer2  total
           display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
   by
         layer1 [c] > (
             driedatbirth  [s] [mean '' f5.1]
           + skintoskin [s] [mean '' f5.1])
           + bathtime [c] [rowpct.validn '' f5.1]
         + numWomen [c] [count '' f5.0]
  /categories variables = all empty = exclude missing = exclude
  /categories variables=bathtime total=yes position= after label= "Total"
  /slabels visible = no
  /titles title=
    "Table TM.8.4: Thermal care for newborns"
    "Percentage of women age 15-49 years with a live birth in the last 2 years whose most recent live-born child was dried after birth and percentage given skin to skin contact and percent distribution of timing of first bath of child, " + surveyname
   caption =
    "[1] MICS indicator TM.14 - Newborns dried"
    "[2] MICS indicator TM.15 - Skin-to-skin care"
    "[3] MICS indicator TM.16 - Delayed bathing"
    "[A] Children never bathed includes children who at the time of the survey had not yet been bathed because they were very young and children dying so young that they were never bathed".																			
  .
  
  * Ctables command in French.
* ctables
  /vlabels variables =  numWomen layer1 layer2  total
           display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
   by
         layer1 [c] > (
             driedatbirth  [s] [mean '' f5.1]
           + skintoskin [s] [mean '' f5.1])
           + bathtime [c] [rowpct.validn '' f5.1]
         + numWomen [c] [count '' f5.0]
  /categories variables = all empty = exclude missing = exclude
  /categories variables=bathtime total=yes position= after label= "Total"
  /slabels visible = no
  /titles title=
    "Tableau TM.8.4: Soins thermaux pour les nouveau-ns"
    "Pourcentage d'enfants ns au cours des deux dernires annes qui ont t schs aprs l'accouchement, pourcentage ayant reu un contact peau  peau et pourcentage de distribution du premier bain, " + surveyname																						
   caption =
    "[1] Indicateur MICS TM.14 - Nouveau-ns schs "
    "[2] Indicateur MICS TM.15 - Soin peau sur peau"
    "[3] Indicateur MICS TM.16 - Bain retard"
    "[A] Les enfants qui ne se sont jamais baigns comprennent les enfants qui, au moment de l'enqute, n'avaient pas encore t baigns parce qu'ils taient trs jeunes et " +
    "que les enfants mouraient si jeunes qu'ils n'avaient jamais t baigns".																			
  .
      
* Ctables command in Spanish.
* ctables
  /vlabels variables =  numWomen layer1 layer2  total
           display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
   by
         layer1 [c] > (
             driedatbirth  [s] [mean '' f5.1]
           + skintoskin [s] [mean '' f5.1])
           + bathtime [c] [rowpct.validn '' f5.1]
         + numWomen [c] [count '' f5.0]
  /categories variables = all empty = exclude missing = exclude
  /categories variables=bathtime total=yes position= after label= "Total"
  /slabels visible = no
  /titles title=
    "Tabla TM.8.4: Cuidado trmico para recin nacidos"
    "Porcentaje de nios nacidos en los ltimos 2 aos que se secaron despus del nacimiento, porcentaje que recibi contacto piel con piel y distribucin porcentual del momento del primer bao, " + surveyname
   caption =
    "[1] Indicador MICS TM.14 - Recin nacidos a los que se sec "
    "[2] Indicador MICS TM.15 - Cuidado piel a piel"
    "[3] Indicador MICS TM.16 - Bao retrasado"
    "[A] Los nios que nunca se baaron incluyen nios que en el momento de la encuesta an no haban sido baados porque eran muy pequeos y los nios que murieron tan jvenes que nunca se les ba".																			
  .

new file.
