* Encoding: windows-1252.
*V2. updated 7 September 2018.
 * "Households that use clean fuels and technologies for cooking (EU1=01, 02, 03, 04, 05, or (EU1=06 and EU4=01).

 * Note: A liquid fuel stove (EU1=06) is considered clean if used with ethanol/alcohol (EU4=01)

 * Denominators are obtained by weighting the number of households by the number of household members (HH48)."																


***.
*v2. 2019-03-14.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'hh.sav'.

select if (HH46  = 1).

compute hhweightHH48 = HH48*hhweight.

weight by hhweightHH48.

compute nhhmem = 1.
variable labels  nhhmem "Number of household members".
value labels nhhmem 1 " ".

* Clean fuels and technologies for cooking (EU1=01, 02, 03, 04, 05, or (EU1=06 and EU4=01)).
recode EU1 (6 thru highest= sysmis) (else=copy) into cleanfuels.
if (EU1=6 and EU4=1) cleanfuels=6.
variable labels cleanfuels "Clean fuels and technologies for cooking and using".
value labels cleanfuels 1 "Electric stove" 2 "Solar cooker" 3 "Liquefied Petroleum Gas (LPG) / Cooking gas stove"
                                    4 "Piped natural gas stove" 5 "Biogas stove" 6 "Liquid fuel stove using alcohol / ethanol".

recode EU1 (1 thru 5= sysmis) (97 thru highest = sysmis) (else=copy) into otherfuels.
if (EU1=6 and EU4<>1) otherfuels=6.
variable labels otherfuels "Other fuels for cooking and using".
value labels otherfuels 6 "Liquid fuel stove not using alcohol / ethanol" 7 "Manufactured solid fuel stove" 8 "Traditional solid fuel stove" 9 "Three stone stove / Open fire" 96 "Other cookstove".									

recode EU1 (1 thru 96 = sysmis) (else=copy) into nofoodother.
variable labels nofoodother " ".
value labels nofoodother 97 "No food cooked in the household" 99 "Missing".	

*Household members living in households that reported cooking (EU1<>97) and using clean fuels and technologies for cooking (EU1=01, 02, 03, 04, 05, or (EU1=06 and EU4=01)).
do if EU1 <> 97.
+compute cleannumnhh=1.
+compute primary = 0 .
+if EU1 <= 5 or (EU1=6 and EU4=1) primary=100.
end if.

variable labels primary "Primary reliance on clean fuels and technologies for cooking (in households that reported cooking) [1]".

variable labels cleannumnhh "Number of household members (living in households that reported cooking)".
value labels cleannumnhh 1 ' '.

compute total = 1.
variable labels  total "Total".
value labels total 1 " ".

compute total100 = 100.
variable labels  total100 "Total".
value labels total100 100 " ".

compute layer = 0.
variable labels  layer "".
value labels layer 0 "Percentage of household members in households with primary reliance on:".


* For labels in French uncomment commands below.
* variable labels
      nhhmem "Nombre de membres du mnage"
	 /cleanfuels "Combustibles et technologies propres pour cuisiner et utiliser"
	 /otherfuels "Autres combustibles pour cuisiner et utiliser"
	 /primary "Recours primaire aux carburants propres et aux technologies de cuisson [1]"
                   /cleannumnhh "Number of household members (living in households that reported cooking)".
* value labels 
      cleanfuels 1 "Cuisiniere electrique" 2 "Cuisiniere solaire" 3 "Cuisiniere a gaz liquide (gpl)"
                                    4 "Cuisiniere a gaz naturel" 5 "Cuisinere a biogaz" 6 "Cuisiniere a combustible liquide alcool / thanol"
	 /otherfuels 6 "Cuisiniere a combustible liquide pas d'alcool / thanol" 7 "Cuisiniere a combustible solide" 
	                                8 "Cuisiniere traditionnelle a combustible solide" 9 "Feu sur trois pierres / feu ouvert" 96 "Other cookstove"
	 /nofoodother  97 "Aucune nourriture cuisine dans le mnage" 99 "Manquant"
	 /layer 0 "Pourcentage des membres du mnage dans les mnages qui comptent principalement sur:".


* For labels in Spanish uncomment commands below.
* variable labels
      nhhmem "Nmero de miembros del hogar"
	 /cleanfuels "Combustibles y tecnologas limpios para cocinar, usando"
	 /otherfuels "Otros combustibles para cocinar, usando"
	 /primary "Dependencia principal en combustibles y tecnologas limpios para cocinar [1]"
                   /cleannumnhh "Number of household members (living in households that reported cooking)".
* value labels 
      cleanfuels 1 "Estufa elctrica" 2 "Cocina solar" 3 "Gas de Petrleo Licuado (LPG)/Estufa de gas"
                                    4 "Estufa de gas natural canalizado" 5 "Estufa de biogs" 6 "Estufa de combustible lquido con alcohol/etanol"
	 /otherfuels 6 "Estufa de combustible lquido que no usa alcohol/etanol" 7 "Estufa de combustible slido fabricada" 
	             8 "Estufa de combustible slido tradicional" 9 "Estufa de tres piedras/fuego abierto" 96 "Other cookstove"
	 /nofoodother 97 "No se cocina comida en el hogar" 99 "Ignorado"
	 /layer 0 "Porcentaje de miembros del hogar en hogares que dependen principalmente de:".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer 
         display = none
  /table   total [c]
         + HH6 [c]  
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
          layer [c] > (cleanfuels [c] [rowpct.totaln '' f5.1]
         + otherfuels [c] [rowpct.totaln '' f5.1]
         + nofoodother [c] [rowpct.totaln '' f5.1])
         + total100 [s] [mean '' f5.1] 
         + nhhmem [c] [count '' f5.0] 
         + primary [s] [mean,'',f5.1]          
         + cleannumnhh [c] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Table TC.4.1: Primary reliance on clean fuels and technologies for cooking"
    "Percent distribution of household members according to type of cookstove mainly used by the " +
     "household and percentage of household members living in households using clean fuels and technologies for cooking, " + surveyname
 caption=
    "[1] MICS indicator TC.15 - Primary reliance on clean fuels and technologies for cooking".
       

* Ctables command in French.
* ctables
  /vlabels variables = layer 
         display = none
  /table   total [c]
         + HH6 [c]  
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
          layer [c] > (cleanfuels [c] [rowpct.totaln '' f5.1]
         + otherfuels [c] [rowpct.totaln '' f5.1]
         + nofoodother [c] [rowpct.totaln '' f5.1])
         + total100 [s] [mean '' f5.1] 
         + primary [s] [mean '' f5.1] 
         + nhhmem [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tableau TC.4.1: Recours primaire aux carburants propres et aux technologies de cuisson"
    "Rpartition en pourcentage des membres du mnage selon le type de cuisinire principalement utilis par le mnage "+
	"et le pourcentage de membres du mnage vivant dans des mnages utilisant des combustibles propres et des technologies pour cuisiner,  " + surveyname
 caption=
    "[1] Indicateur MICS TC.15 - Recours primaire aux carburants propres et aux technologies de cuisson".

* Ctables command in Spanish.
* ctables
  /vlabels variables = layer 
         display = none
  /table   total [c]
         + HH6 [c]  
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
          layer [c] > (cleanfuels [c] [rowpct.totaln '' f5.1]
         + otherfuels [c] [rowpct.totaln '' f5.1]
         + nofoodother [c] [rowpct.totaln '' f5.1])
         + total100 [s] [mean '' f5.1] 
         + primary [s] [mean '' f5.1] 
         + nhhmem [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tabla TC.4.1: Dependencia principal en combustibles y tecnologas limpios para cocinar"
    "Distribucin porcentual de los miembros del hogar de acuerdo al tipo de estufa utilizada principalmente por el hogar "+
	"y el porcentaje de miembros del hogar que viven en hogares que usan combustibles y tecnologas limpios para cocinar,  " + surveyname
 caption=
    "[1] MICS indicador TC.15 - Dependencia principal de combustibles y tecnologas limpios para cocinar".
   	   
new file.
