* Encoding: windows-1252.
*V2. updated 7 September 2018.
 * Households that use clean fuels and technologies for cooking, space heating, and lighting (EU1=01, 02, 03, 04, 05, or (EU1=06 and EU4=01)) AND (EU6=01 OR (EU8=01, 02, 03, 04, 05, OR 06)) AND (EU9=01, 02, 03, 04, OR 05).

 * Denominators are obtained by weighting the number of households by the number of household members (HH48).

* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open household data file.
get file = 'hh.sav'.

select if (HH46 = 1).

sort cases by HH1 HH2.

* Save data file of person collecting water as only variables.
save outfile = 'tmpEU.sav'
  /keep HH1 HH2 EU1 EU4 EU6 EU7 EU8 EU9 .

new file.

get file = 'hl.sav'.

sort cases by HH1 HH2.

* Merge the person collecting the water with the household file. 
match files
  /file = *
  /table = 'tmpEU.sav'
  /by HH1 HH2.

weight by hhweight.

compute primarycooking = 0.
if ((any (EU1, 1,2,3,4,5,97) ) or (EU1 = 6 and EU4 = 1)) primarycooking = 100.
variable labels primarycooking "Primary reliance on clean fuels and technologies for cooking".

compute primaryheating = 0.
if (EU6 = 1 or EU6 = 97 or (any (EU8, 1,2,3,4,5,6) )) primaryheating = 100.
variable labels primaryheating "Primary reliance on clean fuels and technologies for space heating".

compute primarylight = 0. 
 if any(EU9, 1, 2, 3, 4, 5, 97) primarylight = 100 .
variable labels primarylight "Primary reliance on clean fuels and technologies for lighting".

compute primaryall = 0.
if (primarycooking = 100 and primaryheating = 100 and primarylight = 100) primaryall = 100.
variable labels primaryall "Primary reliance on clean fuels and technologies for cooking, space heating and lighting [1],[A]".

* compute total variable.
compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute nhhmem = 1.
variable labels nhhmem "Number of household members".
value labels nhhmem 1 ' '.

* For labels in French uncomment commands below.
* variable labels
     nhhmem "Nombre de membres du mnage"
	 /primaryall  "Primary reliance on clean fuels and technologies for cooking, space heating and lighting [1],[A]"
	 /primarylight "Recours primaire  l'gard des carburants propres et des technologies d'clairage"
	 /primaryheating "Recours primaire aux carburants propres et technologies pour le chauffage des locaux"
	 /primarycooking "Recours primaire aux carburants propres et aux technologies de cuisson ".
	 
* For labels in Spanish uncomment commands below.
* variable labels
     nhhmem "Nmero de miembros del hogar"
	 /primaryall  "Primary reliance on clean fuels and technologies for cooking, space heating and lighting [1],[A]"
	 /primarylight "Dependencia principal en combustibles y tecnologas limpios para iluminacin"
	 /primaryheating "Dependencia principal de combustibles y tecnologas limpios para la calefaccin de espacios"
	 /primarycooking "Dependencia principal en combustibles y tecnologas limpios para cocinar".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = eu9 display = none
  /table total [c]
        + HH6 [c]
        + hh7 [c]
        + helevel [c]
        + ethnicity[c]
        + windex5[c]
   by    primaryall [s] [mean '' f5.1]  + nhhmem [s] [count '' f5.0] 
  /slabels visible = no
  /categories variables = all empty = exclude
  /titles title =
    "Table TC.4.7: Primary reliance on clean fuels and technologies for cooking, space heating, and lighting"
     "Percentage of household members living in households using clean fuels and technologies for cooking, space heating, and lighting, " + surveyname
   caption=
   "[1] MICS indicator TC.18 - Primary reliance on clean fuels and technologies for cooking, space heating, and lighting; SDG Indicator 7.1.2"
   "[A] In order to be able to calculate the indicator, household members living in households that report no cooking, no space heating, or no lighting are not excluded from the numerator"
.
																										

* Ctables command in French.
* ctables
  /vlabels variables = EU9
           display = none
  /table total [c]
        + HH6 [c]
        + hh7 [c]
        + helevel [c]
        + ethnicity[c]
        + windex5[c]
   by    primaryall [s] [mean '' f5.1]  + nhhmem [s] [count '' f5.0] 
  /slabels visible = no
  /categories variables = all empty = exclude
  /titles title =
    "Tableau TC.4.7: Recours primaire aux carburants propres et aux technologies pour la cuisine, le chauffage des locaux et l'clairage "
     "Pourcentage des membres des mnages vivant dans des mnages utilisant des combustibles propres et des technologies pour la cuisine, le chauffage des locaux et l'clairage, " + surveyname
   caption=
   "[A] In order to be able to calculate the indicator, household members living in households that report no cooking, no space heating, or no lighting are not excluded from the numerator"			
   "[1] Indicateur MICS TC.18 - Recours primaire  l'gard des carburants propres et des technologies pour la cuisine, le chauffage des locaux et l'clairage; Indicateur ODD 7.1.2".
		

* Ctables command in Spanish.
* ctables
  /vlabels variables = EU9
           display = none
  /table total [c]
        + HH6 [c]
        + hh7 [c]
        + helevel [c]
        + ethnicity[c]
        + windex5[c]
   by    primaryall [s] [mean '' f5.1]  + nhhmem [s] [count '' f5.0] 
  /slabels visible = no
  /categories variables = all empty = exclude
  /titles title =
    "Tabla TC.4.7: Dependencia principal en combustibles y tecnologas limpios para cocinar, calefaccin de espacios e iluminacin"
     "Porcentaje de miembros del hogar que viven en hogares que usan combustibles y tecnologas limpios para cocinar, calefaccin de espacios e iluminacin, " + surveyname
   caption=
   "[A] In order to be able to calculate the indicator, household members living in households that report no cooking, no space heating, or no lighting are not excluded from the numerator"		
   "[1] MICS indicador TC.18 - Dependencia principal en combustibles y tecnologas limpios para cocinar, calefaccin de espacios e iluminacin; Indicador ODS 7.1.2".
				
new file.

erase file = 'tmpEU.sav'.
