* Encoding: windows-1252.
* MICS6 TC-7.1.
 * Children who were ever breastfed: MN36.

 * Children who started breastfeeding within one hour of birth: MN37=000 (immediately) or MN37=100 (within 1 hour).

 * Children who started breastfeeding within one day of birth: MN37=000 (immediately) or (MN37 >= 100 and MN37 <= 123). Includes children who started breastfeeding within one hour of birth.

 * The table is based on responses of women in the Questionnaire for Individual Women on their last-born children in the 2 years preceding the survey.

 * For the disaggregate of place of delivery, some surveys will find very few cases of home births or births in private facilities. Appropriate combinations can be constructed, e.g. combining 
   public and private or separating 'Other' from 'Other/DK/Missing' and adding home deliveries to 'Other'.
***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

include 'define\MICS6 - 06 - TM.sps' .

select if (CM17 = 1).

* Calculate months since last birth IF last birth in last five years.
compute monthsSinceLastBirth = wdoi - wdoblc.
variable labels monthsSinceLastBirth "Months since last birth".

*Create a recoded months variable since last birth.
recode monthsSinceLastBirth (0 thru 11 = 1)(12 thru 24 = 2) into monthsSinceLastBirthGroups.
variable labels monthsSinceLastBirthGroups "Months since last birth".
value labels monthsSinceLastBirthGroups 
1 " 0-11 months" 
2 "12-23 months".

compute everBreastfed = 0.
if (MN36 = 1) everBreastfed = 100.
variable labels everBreastfed "Percentage who were ever breastfed [1]".

compute layer = 1.
value labels layer 1 "Percentage of children who were first breastfed:".

compute within1hour = 0.
if ((MN37U = 1 and MN37N = 0) or MN37U  = 0) within1hour = 100.
variable labels within1hour "Within one hour of birth [2]".

compute within1day = 0.
if (MN37U = 0 or MN37U = 1) within1day = 100.
variable labels within1day "Within one day of birth".

compute numChildren = 1.
value labels numChildren 1 "Number of most recent live-born children to women with a live birth in the last 2 years".

compute total = 1.
value labels total 1 " ".
variable labels total "Total".

variable labels welevel "Mothers education".

variable labels disability "Mother's functional difficulties (age 18-49 years)".


* For labels in French uncomment commands below.
* variable labels 
    monthsSinceLastBirth "Mois depuis la dernire naissance"
   /monthsSinceLastBirthGroups "Mois depuis la dernire naissance"
   /everBreastfed "Pourcentage de ceux ayant t allaits au sein [1]"
   /within1hour "Dans l'heure qui a suivi la naissance [2]"
   /within1day "Dans la journe qui a suivi la naissance"
   /prelactealFeed "Pourcentage d'enfants de ceux ayant reu une nourriture prlacte [A]"
   /nonmilkbased "Liquides ne sont pas  base de lait"
   /milkbased "Liquides  base de lait"
   /both "Tous les deux"
   /welevel "Instruction de la mre".
* value labels 
    layer 1 "Pourcentage d'enfants qui ont t allaits pour la premire fois:"
    /layer1 1 "Type de nourriture prlacte"
    /numChildren 1 "Number of most recent live-born children to women with a live birth in the last 2 years"
    /numPrelacteal 1 "Nombre de derniers enfants ns vivants au cours des deux dernires annes qui ont t allaits et qui ont reu une nourriture prlacte"
    /numBreastfed 1 "Nombre de derniers enfants ns vivants au cours des deux dernires annes ayant t allaits au sein".

* For labels in Spanish uncomment commands below.
* variable labels 
    monthsSinceLastBirth "Meses desde el nacimiento"
   /monthsSinceLastBirthGroups "Meses desde el nacimiento"
   /everBreastfed "Porcentaje de los que fueron amamantados alguna vez [1]"
   /within1hour "Porcentaje de los que fueron amamantados alguna vez [2]"
   /within1day " En el primer da del nacimiento "
   /prelactealFeed "Porcentaje de los nios/as que recibieron un alimento pre-lcteo [A]"
   /nonmilkbased "Lquidos no basados en leche"
   /milkbased "Lquidos a base de leche"
   /both "Ambos"
   /skilled "Atencin en el parto"
   /welevel "Educacin de la madre".
* value labels 
    layer 1 "Porcentaje de los nios/as que fue amamantado primero:"
    /layer1 1 "Tipo de alimento pre-lcteo"
    /numChildren 1 "Number of most recent live-born children to women with a live birth in the last 2 years"
    /numPrelacteal 1 "Nmero de los ltimos nios/as nacidos en los 2 aos precedentes a la encuesta alguna vez amamantados que recibieron un alimento pre-lcteo"
    /numBreastfed 1 "Nmero de los ltimos nios/as nacidos en los 2 aos precedentes a la encuesta alguna vez amamantados".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = numChildren layer  
           display = none
  /table  total [c]
        + hh6 [c]
        + hh7 [c]
        + monthsSinceLastBirthGroups [c]
        + welevel [c]
        + personAtDelivery1 [c]
        + $deliveryPlace [c]
        + deliveryType [c]
        + disability[c]
        + ethnicity [c]
        + windex5 [c]
   by
          everBreastfed[s][mean '' f5.1]
        + layer [c] > (
            within1hour[s][mean '' f5.1]
          + within1day[s][mean '' f5.1] )
         + numChildren[c][count '' f5.0]
  /slabels visible = no
  /categories variables=all empty=exclude missing=exclude
  /titles title=
        "Table TC.7.1: Initial breastfeeding"
        "Percentage of most recent live-born children to women age 15-49 years with a live birth in the last two years who were ever breastfed, breastfed within one hour of birth and within one day of birth, " + surveyname
  caption=
        "[1] MICS indicator TC.30 - Children ever breastfed"
        "[2] MICS indicator TC.31 - Early initiation of breastfeeding" 
      .							

* Ctables command in French.
* ctables
  /vlabels variables = numChildren layer layer1 numBreastfed numPrelacteal
           display = none
  /table  total [c]
        + hh6 [c]
        + hh7 [c]
        + monthsSinceLastBirthGroups [c]
        + welevel [c]
        + personAtDelivery1 [c]
        + $deliveryPlace [c]
        + deliveryType [c]
        + disability[c]
        + ethnicity [c]
        + windex5 [c]
   by
          everBreastfed[s][mean '' f5.1]
        + layer [c] > (
            within1hour[s][mean '' f5.1]
          + within1day[s][mean '' f5.1] )
         + numChildren[c][count '' f5.0]
        + prelactealFeed[s][mean '' f5.1]
        + numBreastfed[c][count '' f5.0]
        + layer1 [c]> (nonmilkbased [s][mean '' f5.1]+milkbased [s][mean '' f5.1]+both [s][mean '' f5.1])
        + numPrelacteal[c][count '' f5.0]
  /slabels visible = no
  /categories variables=all empty=exclude missing=exclude
  /titles title=
        "Tableau TC.7.1: Allaitement initial au sein"
        "Percentage of most recent live-born children to women age 15-49 years with a live birth in the last two years who were ever breastfed, breastfed within one hour of birth and within one day of birth, " + surveyname
  caption=
        "[1] Indicateur MICS TC.30 - Enfants allaits"
        "[2] Indicateur MICS TC.31 - Dbut de l'allaitement " 
.
								

* Ctables command in Spanish.
* ctables
  /vlabels variables = numChildren layer layer1 numBreastfed numPrelacteal
           display = none
  /table  total [c]
        + hh6 [c]
        + hh7 [c]
        + monthsSinceLastBirthGroups [c]
        + welevel [c]
        + personAtDelivery1 [c]
        + $deliveryPlace [c]
        + deliveryType [c]
        + disability[c]
        + ethnicity [c]
        + windex5 [c]
   by
          everBreastfed[s][mean '' f5.1]
        + layer [c] > (
            within1hour[s][mean '' f5.1]
          + within1day[s][mean '' f5.1] )
         + numChildren[c][count '' f5.0]
        + prelactealFeed[s][mean '' f5.1]
        + numBreastfed[c][count '' f5.0]
        + layer1 [c]> (nonmilkbased [s][mean '' f5.1]+milkbased [s][mean '' f5.1]+both [s][mean '' f5.1])
        + numPrelacteal[c][count '' f5.0]
  /slabels visible = no
  /categories variables=all empty=exclude missing=exclude
  /titles title=
        "Tabla TC.7.1: Lactancia inicial"
        "Percentage of most recent live-born children to women age 15-49 years with a live birth in the last two years who were ever breastfed, breastfed within one hour of birth and within one day of birth, " + surveyname
  caption=
        "[1] MICS indicador TC.30 - Nios que alguna vez fueron amamantados "
        "[2] MICS indicador TC.31 - Iniciacin temprana con leche materna" 
.						


new file.
