* Encoding: windows-1252.
* MICS6 TC-7.3.

 * Children exclusively breastfed: Children currently breastfeeding (BD3=1) and no other liquid or food given (answer must be 2 "No" for all items in questions BD7 and BD8). Any 
   answer to BD4, BD5, and BD6 is permissible.

 * Children predominantly breastfed: Children currently breastfeeding (BD3=1), who are either exclusively breastfed or receiving plain water and non-milk liquids only 
   (answer must be 2 "No" for BD7 groups [E] (Milk) and [D] (Formula) and for all BD8 food groups). BD4, BD5, and BD6 are still permissible.

 * Titles of indicators on continued breastfeeding at 1 and 2 years reflect approximations of the age ranges covered.

***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'ch.sav'.

weight by chweight.

select if (UF17 = 1).

* include definition of solidSemiSoft, exclusivelyBreastfed and predominantlyBreastfed .
include 'define/MICS6 - 07 - TC.sps' .

do if (cage >= 0 and cage <= 5).
+ compute childUpTo5 = 100.
end if.
value labels childUpTo5 100 "Children age 0-5 months".

do if (cage >= 12 and cage <= 15).
+ compute breastfed12_15 = 0.
+ if (BD3 = 1) breastfed12_15 = 100.
end if.
variable labels breastfed12_15 "Children age 12-15 months".

do if (cage >= 20 and cage <= 23).
+ compute breastfed20_23 = 0.
+ if (BD3 = 1) breastfed20_23 = 100.
end if.
variable labels breastfed20_23 "Children age 20-23 months".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

* For labels in French uncomment commands below.
* variable labels 
    breastfed12_15 "Enfants de 12-15 mois"
   /breastfed20_23 "Enfants de 20-23 mois".
* value labels childUpTo5 100 "Enfants de 0-5 mois".

* For labels in Spanish uncomment commands below.
* variable labels 
    breastfed12_15 "Nios/as de 12-15 meses"
   /breastfed20_23 "Nios/as de 20-23 meses".
* value labels childUpTo5 100 "Nios/as de 0-5 meses".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = childUpTo5 exclusivelyBreastfed predominantlyBreastfed
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]         
        + caretakerdis[c]
        + ethnicity [c]
        + windex5 [c]
   by
           childUpTo5 [c] > (
             exclusivelyBreastfed [s] [mean,'Percent exclusively breastfed [1]',f5.1]
           + predominantlyBreastfed [s] [mean,'Percent predominantly breastfed [2]',f5.1
           validn,'Number of children',f5.0] )
         + breastfed12_15 [s] [mean,'Percent breastfed (Continued breastfeeding at 1 year) [3]',f5.1,
                               validn,'Number of children',f5.0]
         + breastfed20_23 [s] [mean,'Percent breastfed (Continued breastfeeding at 2 years) [4]',f5.1,
                               validn,'Number of children',f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
     "Table TC.7.3: Breastfeeding status"
     "Percentage of living children according to breastfeeding status at selected age groups, " + surveyname
   caption=
     "[1] MICS indicator TC.32 - Exclusive breastfeeding under 6 months"
     "[2] MICS indicator TC.33 - Predominant breastfeeding under 6 months"
     "[3] MICS indicator TC.34 - Continued breastfeeding at 1 year"
     "[4] MICS indicator TC.35 - Continued breastfeeding at 2 years"
  .

* Ctables command in French.
* ctables
  /vlabels variables = childUpTo5 exclusivelyBreastfed predominantlyBreastfed
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
        + melevel [c]         
        + caretakerdis[c]
        + ethnicity [c]
        + windex5 [c]
   by
           childUpTo5 [c] > (
             exclusivelyBreastfed [s] [mean,'Pourcentage exclusivement allaits [1]',f5.1]
           + predominantlyBreastfed [s] [mean,'Pourcentage avec allaitement prdominant [2]',f5.1
           validn,'Nombre d'enfants',f5.0] )
         + breastfed12_15 [s] [mean,'Pourcentage allaits (Allaitement continu  1 an) [3]',f5.1,
                               validn,'Nombre d'enfants',f5.0]
         + breastfed20_23 [s] [mean,'Pourcentage allaits (Allaitement continu  2 ans) [4]',f5.1,
                               validn,'Nombre d'enfants',f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
      "Tableau TC.7.3: Status d'allaitement"
     "Pourcentage d'enfants vivants selon le statut d'allaitement par groupes d'ges slectionns, " + surveyname
   caption=
     "[1] Indicateur MICS TC.32 - Allaitement exclusif des moins de 6 mois"
     "[2] Indicateur MICS TC.33 - Allaitement prdominant des moins de 6 mois "
     "[3] Indicateur MICS TC.34 - Allaitement continu  1 an "
     "[4] Indicateur MICS TC.35 - Allaitement continu  2 ans"
  .

* Ctables command in Spanish.
* ctables
  /vlabels variables = childUpTo5 exclusivelyBreastfed predominantlyBreastfed
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]         
        + caretakerdis[c]
        + ethnicity [c]
        + windex5 [c]
   by
           childUpTo5 [c] > (
             exclusivelyBreastfed [s] [mean,'Porcentaje con lactancia exclusivamente [1]',f5.1]
           + predominantlyBreastfed [s] [mean,'Porcentaje con lactancia predominante [2]',f5.1]
           + predominantlyBreastfed [s] [validn,'Nmero de nios/as',f5.0] )
         + breastfed12_15 [s] [mean,'Porcentaje amamantado (lactancia continua 1 ao) [3]',f5.1,
                               validn,'Nmero de nios/as',f5.0]
         + breastfed20_23 [s] [mean,'Porcentaje amamantado (lactancia continua 2 aos) [4]',f5.1,
                               validn,'Nmero de nios/as',f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
      "Tabla TC.7.3: Estado de lactancia"
     "Porcentaje de nios/as vivos de acuerdo al estado de la lactancia en grupos de edad seleccionados, " + surveyname
   caption=
     "[1] MICS indicador TC.32 -  Lactancia exclusiva antes de los 6 meses"
     "[2] MICS indicador TC.33 - Lactancia predominante antes de los 6 meses"
     "[3] MICS indicador TC.34 - Lactancia continua hasta el 1er ao de edad"
     "[4] MICS indicador TC.35 - Lactancia continua hasta los 2 aos de edad"
  .

new file.
