* Encoding: windows-1252.
include "surveyname.sps".

get file = 'hl.sav'.

weight by hhweight.

* Select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your
* country.

* include definition of primarySchoolEntryAge .
include 'define/MICS6 - 08 - LN.sps' .

* Children attending primary school.
do if (ED10A = 1).

compute ageP = 0.
if (schage < primarySchoolEntryAge) ageP = 1.
if (schage >= primarySchoolEntryAge and schage <= primarySchoolCompletionAge) ageP = 2.
if (schage = primarySchoolCompletionAge + 1) ageP = 3.
if (schage > primarySchoolCompletionAge + 1) ageP = 4.

variable labels ageP "Primary school: Percent of children by grade of attendance:".
value labels ageP 1 "Under-age"  2 "At official age" 3 "Over-age by 1 year	" 4 "Over-age by 2 or more [1]".

compute numPrimary = 1.
variable labels numPrimary "Number of children attending primary school".

end if.

* Children attending lower secondary school.
do if (ED10A = 2).

compute ageLS = 0.
if (schage < LowSecSchoolEntryAge) ageLS = 1.
if (schage >= LowSecSchoolEntryAge and schage <= LowSecSchoolCompletionAge) ageLS = 2.
if (schage = LowSecSchoolCompletionAge + 1) ageLS = 3.
if (schage > LowSecSchoolCompletionAge + 1) ageLS = 4.

variable labels ageLS "Lower secondary school: Percent of children by grade of attendance:".
value labels ageLS 1 "Under-age"  2 "At official age" 3 "Over-age by 1 year" 4 "Over-age by 2 or more [2]".

compute numSecondary = 1.
variable labels numSecondary "Number of children attending lower secondary school".

end if.

recode melevel (sysmis = 7) (else = copy).

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

recode ED10B (7 thru hi = sysmis) (else = copy).
variable labels ED10B "Grade".
value labels ED10B
1 "1 (primary/lower secondary)"
2 "2 (primary/lower secondary)"
3 "3 (primary/lower secondary)"
4 "4 (primary)"
5 "5 (primary)"
6 "6 (primary)".

*  For labels in French uncomment commands below.
* variable labels 
      numPrimary "Nombre d'enfants frquentant l'cole primaire"
	 /numSecondary "Nombre d'enfants frquentant le collge".
* variable labels ageP "cole primaire: Pourcentage d'enfants par niveau de frquentation:".
* value labels ageP 1 "Sous-l'ge officiel"  2 " l'ge officiel" 3 "Plus de 1 an" 4 "Plus de 2 ans ou plu [1]".
* variable labels ageLS "Premier cycle du secondaire: Pourcentage d'enfants par niveau de frquentation:".
* value labels ageLS 1 "Sous-l'ge officiel"  2 " l'ge officiel" 3 "Plus de 1 an" 4 "Plus de 2 ans ou plu [2]".
* variable labels ED10B "Niveau scolaire".
* value labels ED10B
1 "1 (primaire / secondaire infrieur)"
2 "2 (primaire / secondaire infrieur)"
3 "3 (primaire / secondaire infrieur)"
4 "4 (primaire)"
5 "5 (primaire)"
6 "6 (primaire)".

*  For labels in Spanish uncomment commands below.
* variable labels 
      numPrimary "Nmero de nios que asisten a la escuela primaria"
	 /numSecondary "Nmero de nios que asisten a la escuela secundaria baja".
* variable labels ageP "Primaria: Porcentaje de nios por grado de asistencia:".
* value labels ageP 1 "Por  debajo de la edad"  2 "En edad oficial" 3 "Extra-edad de 1 ao" 4 "Extra-edad de 2 o ms aos [1]".
* variable labels ageLS "Secundaria baja: Porcentaje de nios por grado de asistencia:".
* value labels ageLS 1 "Por  debajo de la edad"  2 "En edad oficial" 3 "Extra-edad de 1 ao" 4 "Extra-edad de 2 o ms aos [2]".
* variable labels ED10B "Grado".
* value labels ED10B
1 "1 (primaria / secundaria baja)"
2 "2 (primaria / secundaria baja)"
3 "3 (primaria / secundaria baja)"
4 "4 (primaria)"
5 "5 (primaria)"
6 "6 (primaria)".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = numPrimary numSecondary
           display = none
  /table   total [c] 
        + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]         
         + ED10B [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
             ageP[c] [rowpct.validn '' f5.1]
           + numPrimary [s] [validn,'Number of children attending primary school',f5.0] 
           + ageLS [c] [rowpct.validn '' f5.1]
           + numSecondary [s] [validn,'Number of children attending lower secondary school',f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /categories variables=ageP ageLS total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Table LN.2.5: Age for grade"												
     "Percentage of children attending primary and lower secondary school who underage, at age and overage for grade, " + surveyname
   caption = 
          "[1] MICS indicator LN.10a - Over-age for grade (Primary)"												
          "[2] MICS indicator LN.10b - Over-age for grade (Secondary)"												
          "na: not applicable".

* Ctables command in French.  
* ctables
  /vlabels variables = numPrimary numSecondary
           display = none
  /table   total [c] 
        + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]         
         + ED10B [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
             ageP[c] [rowpct.validn '' f5.1]
           + numPrimary [s] [validn,'Nombre d'enfants frquentant l'cole primaire',f5.0] 
           + ageLS [c] [rowpct.validn '' f5.1]
           + numSecondary [s] [validn,'Nombre d'enfants frquentant le collge',f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /categories variables=ageP ageLS total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Tableau LN.2.5: ge par niveau"												
     "Pourcentage d'enfants qui frquentent l'cole primaire et le premier cycle du secondaire et qui ont:  moins que l'ge officiel, l'ge officiel, plus que cet ge, " + surveyname
   caption = 
          "[1] Indicateur MICS LN.10a - Plus g pour le niveau (Primaire)"												
          "[2] Indicateur MICS LN.10b - Plus g pour le niveau (Secondaire)"												
          "na: n'est pas applicable".

* Ctables command in Spanish.  
* ctables
  /vlabels variables = numPrimary numSecondary
           display = none
  /table   total [c] 
        + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]         
         + ED10B [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
             ageP[c] [rowpct.validn '' f5.1]
           + numPrimary [s] [validn,'Nmero de nios que asisten a la escuela primaria',f5.0] 
           + ageLS [c] [rowpct.validn '' f5.1]
           + numSecondary [s] [validn,'Nmero de nios que asisten a la escuela secundaria baja',f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /categories variables=ageP ageLS total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Tabla LN.2.5: Edad para el grado"												
     "Porcentaje de nios que asisten a la escuela primaria y secundaria baja y que son menores que la edad oficial, de los que tienen edad oficial  y de aquellos con extra edad de 1 y 2 o ms aos para el grado, " + surveyname
   caption = 
          "[1] MICS indicador LN.10a - Extra-edad por grado (Primaria)"												
          "[2] MICS indicador LN.10b - Extra-edad por grado (Secundaria baja)"												
          "na: no aplicable".

new file.
