* Encoding: windows-1252.
include "surveyname.sps".

get file = 'hl.sav'.

weight by hhweight.

* Select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your
* country.

* include definition of primarySchoolEntryAge .
include 'define/MICS6 - 08 - LN.sps' .

select if (schage >= UpSecSchoolEntryAge  and schage <= UpSecSchoolCompletionAge).

variable labels schage "Age at beginning of school year".

compute secondary  = 0.
if (ED10A >= 3 and ED10A <= 5) secondary =  100.

* Set test for "Age at the begining of school year" equal to age in last grade of secondary and test for ED4B equal to the last grade of secondary.
if (ED5A = 3 and ED5B = UpSecSchoolGrades and ED6 = 1 and ED9 = 2) secondary  = 100.

compute primary  = 0.
if (ED10A = 1) primary =  100.

compute lowsecondary  = 0.
if (ED10A = 2) lowsecondary =  100.

* The percentage of children out of school are those who are not attending upper secondary school or higher, those who are not attending primary school or lower secondary school, 
and those who have not already completed upper secondary school: ED9=2 and (ED5A=3 and ED5B=last grade of upper secondary school and ED6<>1)).
compute outOfSchool = 0 .
if (ED9 = 2 or ED4 = 2) outOfSchool = 100.
if (ED5A = 3 and ED5B = UpSecSchoolGrades and ED6 = 1 and ED9 = 2) outOfSchool  = 0.

recode melevel (sysmis = 7) (else = copy).
add value labels melevel 7 "No information [B]".

add value labels caretakerdis 7 "No information [B]".

variable labels primary "".
variable labels lowsecondary "".
variable labels secondary "".
variable labels outOfSchool "".
variable labels HL4 "".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute layer = 1.
value labels layer 1 "Percentage of children:".

*  For labels in French uncomment commands below.
* variable labels schage "ge au dbut de l'anne scolaire".
* add value labels caretakerdis 7 "Aucune information [B]".
* add value labels melevel 7 "Aucune information [B]".

*  For labels in Spanish uncomment commands below.
* variable labels schage "Edad al inicio del ao escolar".
* add value labels caretakerdis 7 "No hay informacin [B]".
* add value labels melevel 7 "No hay informacin [B]".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = hl4 secondary lowsecondary primary outOfSchool layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
           hl4 [c] > (
             secondary [s] [mean,'Net attendance ratio (adjusted) [1]',f5.1]
           + layer [c] > (lowsecondary  [s] [mean,'Attending lower secondary school',f5.1]
           + primary   [s] [mean,'Attending primary school',f5.1]
           + outOfSchool [s] [mean,'Out of school [A]',f5.1])
           + secondary [s] [validn,'Number of children of upper secondary school age at beginning of school year',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Table LN.2.6: Upper secondary school attendance and out of school youth"												
    "Percentage of children of upper secondary school age attending upper secondary school or higher (adjusted net attendance ratio), percentage attending lower secondary school, and percentage out of school, " + surveyname
   caption =
    "[1] MICS indicator LN.5c - Upper secondary school net attendance ratio (adjusted)"															
    "[2] MICS indicator LN.6c - Out-of-school rate for youth of upper secondary school age"																
    "[A] The percentage of children of upper secondary school age out of school are those who are not attending primary, secondary or higher education"																
    "[B] Children age 18 or higher at the time of the interview".


* Ctables command in French.  
* ctables
  /vlabels variables = hl4 secondary lowsecondary primary outOfSchool layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
    by
           hl4 [c] > (
             secondary [s] [mean,'Net attendance ratio (adjusted) [1]',f5.1]
           + layer [c] > (lowsecondary  [s] [mean,'Attending lower secondary school',f5.1]
           + primary   [s] [mean,'Attending primary school',f5.1]
           + outOfSchool [s] [mean,'Out of school [A]',f5.1])
           + secondary [s] [validn,'Number of children of upper secondary school age at beginning of school year',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Tableau LN.2.6: Frquentation scolaire dans l'enseignement secondaire 2eme cycle et jeunes non scolariss"												
    "Pourcentage d'enfants d'age du Secondaire 2eme cycle frquentant l'cole secondaire 2eme cycle ou suprieure " +
    "(taux net scolarisation ajust), pourcentage d'lves frquentant le Secondaire 1er cycle, et pourcentage d'enfants en dehors de l'ecole, " + surveyname
   caption =
    "[1] Indicateur MICS LN.5c - Taux net de scolarisation dans l'enseignement secondaire 2eme cycle (ajust)"															
    "[2] Indicateur MICS LN.6c - Taux non frequentation scolaire pour les jeunes en ge d'aller  l'cole secondaire 2eme cycle"																
    "[A] Le pourcentage d'enfants en age de scolarisation Secondaure 2eme cycle en dehors de l'ecole concerne ceux qui ne frquentent pas l'ecole primaire, secondaire ou suprieur"																
    "[B] Enfants gs de 18 ans ou plus au moment de l'interview".

* Ctables command in Spanish.  
* ctables
  /vlabels variables = hl4 secondary lowsecondary primary outOfSchool layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
           hl4 [c] > (
             secondary [s] [mean,'Net attendance ratio (adjusted) [1]',f5.1]
           + layer [c] > (lowsecondary  [s] [mean,'Attending lower secondary school',f5.1]
           + primary   [s] [mean,'Attending primary school',f5.1]
           + outOfSchool [s] [mean,'Out of school [A]',f5.1])
           + secondary [s] [validn,'Number of children of upper secondary school age at beginning of school year',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
     "Tabla LN.2.6: Asistencia a la escuela secundaria alta y jvenes que no asisten a la escuela"												
    "Porcentaje de nios en edad de asistir a la escuela secundaria alta que asisten a la escuela secundaria o superior " +
    "(tasa neta de asistencia ajustada), porcentaje que asistencia a la escuela secundaria baja y porcentaje que no asisten a la escuela, " + surveyname																																						 
   caption =
    "[1] MICS indicador LN.5c -  Tasa neta de asistencia a la escuela secundaria alta (ajustada)"															
    "[2] MICS indicador LN.6c - Tasa de desercin escolar para jvenes en edad de asistir a la escuela secundaria alta"																
    "[A] El porcentaje de nios en edad de asistir a la escuela secundaria alta fuera de la escuela son aquellos que no asisten a la escuela primaria, secundaria o educacin superior"																
    "[B] Jvenes de 18 aos o ms en el momento de la entrevista".




new file.
