* Encoding: windows-1252.
***.
* v02 - 2019-08-27. Last modified to reflect tab plan changes as of 25 July 2019.

include "surveyname.sps".

get file = 'fs.sav'.

include "CommonVarsFS.sps".

select if (FS17 = 1).

weight by fsweight.

* definitions of econcomic activity variables  (ea1more, ea14less, ea14more, ea43less, ea43more) .
include 'define\MICS6 - 09 - PR.sps' .

variable labels
   ea1more  "Percentage of children age 5-11 years involved in economic activity for at least one hour"
  /ea14less "Economic activity less than 14 hours"
  /ea14more "Economic activity for 14 hours or more" 
  /ea43less "Economic activity less than 43 hours"
  /ea43more "Economic activity for 43 hours or more" .

compute layerPercentage12_14 = numChildren12_14 . 
compute layerPercentage15_17 = numChildren15_17 . 

value labels
   numChildren5_11      1 "Number of children age 5-11 years"
  /numChildren12_14     1 "Number of children age 12-14 years"
  /numChildren15_17     1 "Number of children age 15-17 years"
  /layerPercentage12_14 1 "Percentage of children age 12-14 years involved in:"
  /layerPercentage15_17 1 "Percentage of children age 15-17 years involved in:" .

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

variable labels schoolAttendance "School attendance".
value labels schoolAttendance 1 "Attending [A]" 2 "Not attending" .

add value labels melevel 7 'No information [B]'.
variable labels fsdisability "Child's functional difficulties".
variable labels caretakerdis "Mother's functional difficulties (age 18-49 years)".

*  For labels in French uncomment commands below.
* variable labels schoolAttendance "Frquentation scolaire".
* value labels schoolAttendance 1 "Frequente l'cole [A]" 2 "Ne frequenet pas l'cole" .
* add value labels melevel 7 'Aucune information [B]'.
* variable labels 
   ea1more  "Pourcentage d'enfants gs de 5  11 ans impliqus dans l'activit conomique pendant au moins une heure "
  /ea14less "Activit conomique moins de 14 heures "
  /ea14more "Activit conomique pendant 14 heures ou plus " 
  /ea43less "Activit conomique moins de 43 heures "
  /ea43more "Activit conomique pendant 43 heures ou plus " 
  /fsdisability "Child's functional difficulties"
  /caretakerdis "Mother's functional difficulties (age 18-49 years)".
* value labels
   numChildren5_11      1 "Nombre d'enfants gs de 5  11 ans"
  /numChildren12_14     1 "Nombre d'enfants gs de 12  14 ans"
  /numChildren15_17     1 "Nombre d'enfants gs de 15  17 ans"
  /layerPercentage12_14 1 "Pourcentage d'enfants gs de 12  14 ans impliqus dans:"
  /layerPercentage15_17 1 "Pourcentage d'enfants gs de 15  17 ans impliqus dans:" .


*  For labels in Spanish uncomment commands below.
* variable labels schoolAttendance "Asistencia a la escuela".
* value labels schoolAttendance 1 "Asiste [A]" 2 "No asiste" .
* add value labels melevel 7 'Sin informacin [A]'.

* variable labels 
   ea1more  "Porcentaje de nios/as de 5-11 aos que participan en actividades econmicas por al menos una hora "
  /ea14less "Actividad econmica menos de 14 horas"
  /ea14more "Actividad econmica por 14 horas o ms " 
  /ea43less "Actividad econmica menos de 43 horas"
  /ea43more "Actividad econmica por 43 horas o ms"
  /fsdisability "Child's functional difficulties"
  /caretakerdis "Mother's functional difficulties (age 18-49 years)".
* value labels
   numChildren5_11      1 "Nmero de nios/as de 5-11 aos"
  /numChildren12_14     1 "Nmero de nios/as de 12-14 aos"
  /numChildren15_17     1 "Nmero de nios/as de 15-17 aos"
  /layerPercentage12_14 1 "Porcentaje de nios/as de 12-14 aos que participaron en:"
  /layerPercentage15_17 1 "Porcentaje de nios/as de 15-17 aos que participaron en:" .

  
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /format missing = "na" 
  /vlabels variables = numChildren5_11 numChildren12_14 numChildren15_17 layerPercentage12_14 layerPercentage15_17
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schoolAttendance [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           ea1more[s] [mean '' f5.1]
         + numChildren5_11 [c] [count '' f5.0]
         + layerPercentage12_14 [c] > (
             ea14less [s] [mean '' f5.1]
           + ea14more [s] [mean '' f5.1] )
         + numChildren12_14 [c] [count '' f5.0]
         + layerPercentage15_17 [c] > (
             ea43less [s] [mean '' f5.1]
           + ea43more [s] [mean '' f5.1] )
         + numChildren15_17 [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table PR.3.1: Children's involvement in economic activities"
  	 "Percentage of children age 5-17 years by involvement in economic activities during the previous week, by age groups, " + surveyname
   caption=
     "[A] Includes attendance to early childhood education"						
     "[B] Children age 15 or higher identified as emancipated"						
     "na: not applicable".

* Ctables command in French.  
* ctables
  /format missing = "na" 
  /vlabels variables = numChildren5_11 numChildren12_14 numChildren15_17 layerPercentage12_14 layerPercentage15_17
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schoolAttendance [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           ea1more[s] [mean '' f5.1]
         + numChildren5_11 [c] [count '' f5.0]
         + layerPercentage12_14 [c] > (
             ea14less [s] [mean '' f5.1]
           + ea14more [s] [mean '' f5.1] )
         + numChildren12_14 [c] [count '' f5.0]
         + layerPercentage15_17 [c] > (
             ea43less [s] [mean '' f5.1]
           + ea43more [s] [mean '' f5.1] )
         + numChildren15_17 [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau PR.3.1: Implication des enfants dans les activits conomiques"
  	 "Percentage of children age 5-17 years by involvement in economic activities during the previous week, by age groups, " + surveyname
   caption=
     "[A] Includes attendance to early childhood education"						
     "[B] Children age 15 or higher identified as emancipated"						
     "na: not applicable".
	 
* Ctables command in Spanish.  
* ctables
  /format missing = "na" 
  /vlabels variables = numChildren5_11 numChildren12_14 numChildren15_17 layerPercentage12_14 layerPercentage15_17
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schoolAttendance [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           ea1more[s] [mean '' f5.1]
         + numChildren5_11 [c] [count '' f5.0]
         + layerPercentage12_14 [c] > (
             ea14less [s] [mean '' f5.1]
           + ea14more [s] [mean '' f5.1] )
         + numChildren12_14 [c] [count '' f5.0]
         + layerPercentage15_17 [c] > (
             ea43less [s] [mean '' f5.1]
           + ea43more [s] [mean '' f5.1] )
         + numChildren15_17 [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla PR.3.1: Participacin de los nios/as en las actividades econmicas"
  	 "Percentage of children age 5-17 years by involvement in economic activities during the previous week, by age groups, " + surveyname
   caption=
     "[A] Includes attendance to early childhood education"						
     "[B] Children age 15 or higher identified as emancipated"						
     "na: not applicable".

new file.
