﻿* Encoding: windows-1252.
 * "Women who think that their life has improved during the last one year: LS3=1.
 * Women who expect that their life will get better after one year: LS4=1.
 * Women who think their life has been improving and will continue to improve: (LS3=1 and LS4=1)."									

***.

* v02 - 2019-08-28. Last modified to reflect tab plan changes as of 25 July 2019.

include "surveyname.sps".

get file="wm.sav".

include "CommonVarsWM.sps".

select if (WM17 = 1).

* Weight the data by the women weight.
weight by wmweight.

* Generate total variable.
compute numWomen = 1.
variable labels numWomen "Number of women age 15-49 years".

compute lifeimproved=0.
if LS3=1 lifeimproved=100.
variable labels lifeimproved "Improved during the last one year".

compute lifebetter=0.
if LS4=1 lifebetter=100.
variable labels lifebetter "Will get better after one year".

compute lifeboth=0.
if (LS3=1 and LS4=1) lifeboth=100.
variable labels lifeboth "Both [2]".


do if (wage <=2).
+compute numWomen1524 = 1.
+variable labels numWomen1524 "Number of women age 15-24 years".
+ compute lifeimproved1524=0.
+ if LS3=1 lifeimproved1524=100.
+ compute lifebetter1524=0.
+ if LS4=1 lifebetter1524=100.
+ compute lifeboth1524=0.
+ if (LS3=1 and LS4=1) lifeboth1524=100.
end if.

variable labels lifeimproved1524 "Improved during the last one year".
variable labels lifebetter1524 "Will get better after one year".
variable labels lifeboth1524 "Both [1]".

compute layer1 = 1.
variable labels layer1 "".
value labels layer1 1 "Percentage of women age 15-24 years who think that their life".
compute layer2 = 1.
variable labels layer2 "".
value labels layer2 1 "Percentage of women age 15-49 years who think that their life".

compute total = 1.
variable labels total "".
value labels total 1 "Total".

*  For labels in French uncomment commands below.
* variable labels
	  numWomen "Nombre de femmes âgées de 15-49 ans "
	  /lifeimproved "Amélioré au cours de la dernière année "
      /lifebetter "S'améliorera après un an "
      /lifeboth "Tous les deux [2]"
	  /numWomen1524 "Nombre de femmes âgées de 15-24 ans "
	  /lifeimproved1524 "Amélioré au cours de la dernière année "
      /lifebetter1524 "S'améliorera après un an "
      /lifeboth1524 "Tous les deux [1]".    
* value labels 
	layer1 1 "Pourcentage de femmes âgées de 15 à 24 ans qui pensent que leur vie "
	/layer2 1 "Pourcentage de femmes âgées de 15 à 49 ans qui pensent que leur vie ".
	
	
*  For labels in Spanish uncomment commands below.
* variable labels
	numWomen "Número de mujeres de 15-49 años"
	/numWomen1524 "Número de mujeres de 15-24 años"
     /lifeimproved "Mejoraron durante el último año "
      /lifebetter "Estarán mejor dentro de un año "
      /lifeboth "Ambos [2]"
	  /lifeimproved1524 "Mejoraron durante el último año "
      /lifebetter1524 "Estarán mejor dentro de un año "
      /lifeboth1524 "Ambos [1]".    
* value labels 
	layer1 1 "Porcentaje de mujeres de 15-24 años de edad que piensan que sus vidas  "
	/layer2 1 "Porcentaje de mujeres de 15-49 años de edad que piensan que sus vidas  ".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  total layer1 layer2
         display = none
  /format missing = "na" 
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus2 [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
     by
          layer1 [c] > 
           (lifeimproved1524 [s] [mean '' f5.1]
        + lifebetter1524 [s] [mean '' f5.1]
        + lifeboth1524 [s] [mean '' f5.1]) 
        + numWomen1524 [s] [sum, '', f5.0]
        + layer2 [c] > 
           (lifeimproved [s] [mean '' f5.1]
        + lifebetter [s] [mean '' f5.1]
        + lifeboth [s] [mean '' f5.1])
        + numWomen [s] [sum, '', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table EQ.4.2W: Perception of a better life (women)"
     "Percentage of women age 15-24 and 15-49 years who think that their lives improved during the last one year and those who expect that their lives will get better after one year, " + surveyname
   caption=
 "[1] MICS indicator EQ.11a - Perception of a better life among women age 15-24 years" 
 "[2] MICS indicator EQ.11b - Perception of a better life among women age 15-49 years" 
 "na: not applicable".							


* Ctables command in French.  
* ctables
  /vlabels variables =  total layer1 layer2
         display = none
  /format missing = "na" 
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus2 [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
     by
          layer1 [c] > 
           (lifeimproved1524 [s] [mean '' f5.1]
        + lifebetter1524 [s] [mean '' f5.1]
        + lifeboth1524 [s] [mean '' f5.1]) 
        + numWomen1524 [s] [sum, '', f5.0]
        + layer2 [c] > 
           (lifeimproved [s] [mean '' f5.1]
        + lifebetter [s] [mean '' f5.1]
        + lifeboth [s] [mean '' f5.1])
        + numWomen [s] [sum, '', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau EQ.4.2W: Perception d'une vie meilleure (femmes)"
     "Percentage of women age 15-24 and 15-49 years who think that their lives improved during the last one year and those who expect that their lives will get better after one year, " + surveyname
   caption=
 "[1]  Indicateur MICS EQ.11a - Perception d'une vie meilleure parmi les femmes de 15-24 ans" 
 "[2]  Indicateur MICS EQ.11b - Perception d'une vie meilleure parmi les femmes de 15-49 ans" 
 "na: n'est pas applicable".

 
* Ctables command in Spanish.  
* ctables
  /vlabels variables =  total layer1 layer2
         display = none
  /format missing = "na" 
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus2 [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
     by
          layer1 [c] > 
           (lifeimproved1524 [s] [mean '' f5.1]
        + lifebetter1524 [s] [mean '' f5.1]
        + lifeboth1524 [s] [mean '' f5.1]) 
        + numWomen1524 [s] [sum, '', f5.0]
        + layer2 [c] > 
           (lifeimproved [s] [mean '' f5.1]
        + lifebetter [s] [mean '' f5.1]
        + lifeboth [s] [mean '' f5.1])
        + numWomen [s] [sum, '', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla EQ.4.2W: Percepción de una vida mejor (mujeres)"
     "Percentage of women age 15-24 and 15-49 years who think that their lives improved during the last one year and those who expect that their lives will get better after one year, " + surveyname
   caption=
 "[1]  MICS indicador EQ.11a - Percepción de una vida mejor entre mujeres de 15-24 años de edad " 
 "[2]  MICS indicador EQ.11b - Percepción de una vida mejor entre mujeres de 15-49 años de edad" 
 "na: no aplicable".

new file.
